package com.chinaitop.depot.basic.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import com.chinaitop.depot.basic.model.MonitorNvr;
import com.chinaitop.depot.basic.service.MonitorNvrService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.chinaitop.depot.basic.model.MonitorCamera;
import com.chinaitop.depot.basic.model.MonitorCameraExample;
import com.chinaitop.depot.basic.service.MonitorCameraService;
import com.chinaitop.depot.basic.service.impl.CameraStorehouseServiceImpl;
import com.chinaitop.depot.basic.service.impl.ImportServiceImpl;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 摄像头操作类
 */
@RestController
@RequestMapping(value="/camera")
@Api(value= "MonitorCameraController", description = "摄像头操作类")
public class MonitorCameraController {

    @SuppressWarnings("unused")
	private static Logger log = LoggerFactory.getLogger(MonitorCameraController.class);

    @Resource
    private MonitorCameraService cameraService;

    @Resource
    private MonitorNvrService nvrService;
    
    @Resource
    private ImportServiceImpl importService;
    
    @Resource
    private CameraStorehouseServiceImpl cameraStorehouseService;

    @Value("${web.upload-path}")
    private String uploadPath;

    @RequestMapping(value="/getCamera", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查找摄像头信息", notes = "查找摄像头信息，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "cameraName", value = "摄像头名称", paramType = "query"),
        @ApiImplicitParam(name="orgid", value="组织机构id", paramType="query")
	})
    public PageInfo<MonitorCamera> getCamera(Integer pageNum, Integer pageSize,String cameraName,Integer orgid) {

        MonitorCameraExample example = new MonitorCameraExample();
        MonitorCameraExample.Criteria criteria = example.createCriteria();
        criteria.andIsremoveEqualTo("1");//默认加载未删除的数据

        if (ParameterUtil.isnotnull(cameraName))
            criteria.andAliasLike("%"+cameraName+"%");

        criteria.andOrgIdEqualTo(orgid.toString());//添加组织

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<MonitorCamera> list = cameraService.queryByExample(example);
        PageInfo<MonitorCamera> pageInfo = new PageInfo<MonitorCamera>(list);
        return pageInfo;
    }

    @RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="根据id查找摄像头信息", notes = "根据id查找摄像头信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
	})
    public Map<String, Object> edit(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (id != null) {
            MonitorCamera camera = cameraService.findById(id);
            modelMap.put("cameraEdit",camera);

            MonitorNvr nvr = nvrService.loadDataById(Integer.parseInt(camera.getNvrId()));
            modelMap.put("nvrEdit",nvr);
        }
        return modelMap;
    }

    @RequestMapping(value="/saveCamera", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存摄像头信息", notes = "保存摄像头信息")
//	@ApiImplicitParams({
//		@ApiImplicitParam(name = "cameraJson", value = "摄像头数据", paramType = "form"),
//		@ApiImplicitParam(name = "nvrId", value = "硬盘录像机ID", paramType = "form")
//	})
    public Map<String, Object> saveCamera(@RequestBody MonitorCamera camera) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
       // MonitorCamera camera = (MonitorCamera)mapper.readValue(cameraJson, MonitorCamera.class);
        camera.setIsremove("1");//默认设置删除标志
        camera.setUpdateTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改时间
        //camera.setNvrId(nvrId);
        if (camera.getId() == null) {
            cameraService.add(camera);
        } else {
            cameraService.update(camera);
        }
        //先删除摄像头仓房管理信息
        cameraStorehouseService.deleteById(camera.getId());
        if(camera.getLive().equals("1")) {//只有仓内摄像头才关联仓房信息
        	//保存摄像头仓房管理信息
        	if(!camera.getStorehouseId().isEmpty()) {
        		cameraStorehouseService.add(camera);
        	}
        }
        
        modelMap.put("status", "success");
        return modelMap;
    }

    @RequestMapping(value="/removeCamera", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="删除摄像头信息", notes = "删除摄像头信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "主键id", paramType = "form")
	})
    public Map<String, Object> removeCamera(Integer id) throws IOException {
        Map<String, Object> modelMap = new HashMap<>();
        if (id != null) {
            cameraService.updateDeleteById(id);
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    @RequestMapping(value="/getNVRVideo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查找要录像的NVR信息", notes = "查找要录像的NVR信息")
    @ApiImplicitParams({
        @ApiImplicitParam(name="orgid", value="组织机构id", paramType="query")
    })
    public List<Map<String,Object>> getNVRVideo(Integer orgid) {
        Map<String,Object> map = new HashMap<>();
        map.put("orgid",orgid.toString());
        List<Map<String,Object>> list = cameraService.selectByNVRDates(map);
        return ParameterUtil.slashCapitals(list);
    }

    @RequestMapping(value="/getAgentVideo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查找要代储库的NVR信息", notes = "查找要代储库的NVR信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name="orgid", value="组织机构id", paramType="query")
    })
    public List<List<Map<String,Object>>> getAgentVideo(Integer orgid) {
        Map<String,Object> map = new HashMap<>();
        map.put("nowOrgid",orgid.toString());
        //先查询出来粮库下边的所有代储库
        List<Map<String,Object>> depotList = cameraService.getAgentDepot(map);
        List<List<Map<String,Object>>> list = new ArrayList<List<Map<String,Object>>>();
        for (Map<String,Object> depot : depotList) {
            map.put("orgid",depot.get("depotid"));
            List<Map<String,Object>> cameraList = cameraService.getAgentVideo(map);
            if(cameraList!=null&&!cameraList.isEmpty()){
                list.add(ParameterUtil.slashCapitals(cameraList));
            }
        }
        return list;
    }
    /**
     * 导入excel
     * @param file 文件
     * @param fileType 类型：如xlsx
     * @return
     */

    @RequestMapping(value="/importFile", method=RequestMethod.POST)
    @ApiOperation(value="导入摄像头excel", notes = "导入摄像头excel")
    public String importFile(MultipartFile file,String orgId, String fileType, HttpServletRequest request){

        String[] titleArr = {"摄像头名称", "摄像机别名", "所属厂商(200代表海康，300代表大华)", "账号", "密码", "硬盘录像机编号", "通道号", "IP地址",
        		"子网掩码", "网关", "设备类型(1代表球形摄像机,2代表枪式摄像机)", "设备端口", "设备型号", "所在位置(1代表仓内,2代表仓外)",
        		"设备序列号", "安装位置", "安装方式", "照射区域", "取电位置", "仓房名称","摄像头唯一标识","在线状态（0-未知，1-在\n" +
                "线，2-离线）","状态说明"};//第一行的title
        boolean[] emptyArr = {false, false, false, false, false, false, false, false,
        		true, true, false, false, true, true,
        		true, true, true, true, true,true,false,true,true};//指定列可为空，不可为空值为false.
        String orgId1=orgId.replaceAll("\\D+", "");
        List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
        String errormsg = null;
        try {

        	errormsg = importService.importFile(uploadPath, file, fileType,request,titleArr, emptyArr, list);

        	if (errormsg != null && !"".equals(errormsg)) {
        		return errormsg;
        	}

            if (list.size()>0) {
            	errormsg = cameraService.importData(list, Integer.parseInt(orgId1));

            	System.out.println(list);
            	System.out.println(errormsg);
            	//errormsg = "导入成功！";
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return errormsg;
    }
}
