package com.chinaitop.depot.basic.controller;

import com.chinaitop.depot.basic.model.MonitorCamera;
import com.chinaitop.depot.basic.model.MonitorCameraExample;
import com.chinaitop.depot.basic.model.MonitorNvr;
import com.chinaitop.depot.basic.model.MonitorNvrExample;
import com.chinaitop.depot.basic.service.MonitorCameraService;
import com.chinaitop.depot.basic.service.MonitorNvrService;
import com.chinaitop.depot.basic.service.impl.ImportServiceImpl;
import com.chinaitop.depot.monitor.util.MonitorZD;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 该类为nvr操作类
 * @author mafy
 */
@RestController
@RequestMapping(value = "/nvr")
@Api(value= "MonitorNvrController", description = "该类为nvr操作类")
public class MonitorNvrController {

    @SuppressWarnings("unused")
	private static Logger log = LoggerFactory.getLogger(MonitorCameraController.class);

    @Resource
    private MonitorNvrService nvrService;

    @Resource
    private MonitorCameraService cameraService;

    @Resource
    private ImportServiceImpl importService;

    @Value("${web.upload-path}")
    private String uploadPath;

    @RequestMapping(value="/getNvr", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询nvr列表", notes = "条件查询nvr列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "nvrName", value = "NVR名称", paramType = "query"),
        @ApiImplicitParam(name = "orgid", value = "组织机构id", paramType = "query")
	})
    public PageInfo<MonitorNvr> getNvr(Integer pageNum, Integer pageSize, String nvrName,Integer orgid) {

        MonitorNvrExample example = new MonitorNvrExample();
        MonitorNvrExample.Criteria criteria = example.createCriteria();
        criteria.andDeleteMarkEqualTo("1");//默认加载未删除的数据

        if (ParameterUtil.isnotnull(nvrName))
        criteria.andAliasLike("%" + nvrName + "%");
        criteria.andOrgIdEqualTo(orgid.toString());

        PageHelper.startPage(pageNum, pageSize);
        List<MonitorNvr> list = nvrService.selectByExample(example);
        PageInfo<MonitorNvr> pageInfo = new PageInfo<MonitorNvr>(list);
        return pageInfo;
    }

    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="新增和修改的数据进行保存", notes = "新增和修改的数据进行保存")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "nvrJson", value = "NVR数据", paramType = "form"),
		@ApiImplicitParam(name = "orgid", value = "组织机构id", paramType = "form")
	})
    public Map<String, Object> save(String nvrJson,Integer orgid) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        MonitorNvr monitorNvr = null;
        try {
            monitorNvr = (MonitorNvr) mapper.readValue(nvrJson, MonitorNvr.class);
            monitorNvr.setDeleteMark("1");//默认设置删除标志
            monitorNvr.setOrgId(orgid.toString());
            monitorNvr.setUpdateTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改时间
            nvrService.save(monitorNvr);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="根据主键id移除数据", notes = "根据主键id移除数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "主键ID", paramType = "form")
	})
    public Map<String, Object> remove(Integer id) {
        Map<String, Object> retMap = new HashMap<String, Object>();
        nvrService.remove(id);
        retMap.put("msg", "success");
        return retMap;
    }

    @RequestMapping(value="/loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键ID", paramType = "query")
    })
    public MonitorNvr loadDataById(int id) {
        return nvrService.loadDataById(id);
    }

    @RequestMapping(value="/getThroughByNVRId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="根据nvrId获取通道列表", notes = "根据nvrId获取通道列表")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "nvrId", value = "主键ID", paramType = "query")
	})
    public List<Map<String, Object>> getThroughByNVRId(Integer nvrId) {

        return ParameterUtil.slashCapitals(nvrService.getThroughByNVRId(nvrId));
    }

    @RequestMapping(value="/saveChannelNumber", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="更新通道号信息", notes = "更新通道号信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "nvrId", value = "主键ID", paramType = "form"),
		@ApiImplicitParam(name = "nvrIp", value = "nvrIP地址", paramType = "form"),
		@ApiImplicitParam(name = "nvrUsername", value = "nvr账号", paramType = "form"),
		@ApiImplicitParam(name = "nvrPassword", value = "nvr密码", paramType = "form"),
		@ApiImplicitParam(name = "nvrPort", value = "nvr端口", paramType = "form"),
		@ApiImplicitParam(name = "nvrType", value = "nvr类型", paramType = "form")
	})
    public Map<String, Object> saveChannelNumber(String nvrId, String nvrIp, String nvrUsername, String nvrPassword, Integer nvrPort, Integer nvrType) {
        Map<String, Object> modelMap = new HashMap<>();
        List<Map<String, Object>> channel = new ArrayList<>();
        try {
            System.out.println(System.getProperty("java.library.path"));
            //诊断对象
            MonitorZD dm = null;
            System.loadLibrary("MonitorZD");
            dm = new MonitorZD();
            //加载信息
    //        dm.InitLog("E:/monitor_zd.log");
            dm.InitHCSdk();
            dm.InitDHSdk();
            String IPC = dm.NVRGETIP(nvrIp, nvrPort, nvrUsername, nvrPassword, nvrType);
            String[] value = IPC.split("IPC");
            List<String> cameraIp = new ArrayList<>();
            for (int i = 0; i < value.length; i++) {
                String[] MYIPC = value[i].split("\\|F-G\\|");
                if(MYIPC[0].length()>0){
                    if ("0.0.0.0" == MYIPC[0] || "0.0.0.0".equals(MYIPC[0])) {
                        System.out.println("1");
                    } else {
                        String isNotNull = MYIPC[0].substring(MYIPC[0].length() - 3, MYIPC[0].length());
                        if (!isNotNull.equals("0.0")) {
                            cameraIp.add(MYIPC[0]);
                            Map<String, Object> retMap = new HashMap<String, Object>();
                            retMap.put("ip", MYIPC[0]);
                            retMap.put("tdh", Integer.valueOf(MYIPC[1])-1);
                            channel.add(retMap);
                        System.out.println("搜索到设备IP:"+MYIPC[0]+";通道号:"+MYIPC[1]);
                        }
                    }
                }
            }
            dm.CleanDHSdk();
            dm.CleanHCSdk();
            getCameraName(cameraIp,channel,nvrId);
            modelMap.put("msg", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 向集合中添加摄像头名称
     *
     * @param cameraIp
     * @param channel
     * @return
     */
    public void getCameraName(List<String> cameraIp, List<Map<String, Object>> channel,String nvrId) {
        MonitorCameraExample example = new MonitorCameraExample();
        MonitorCameraExample.Criteria criteria = example.createCriteria();
        criteria.andIpIn(cameraIp);

        List<MonitorCamera> list = cameraService.queryByExample(example);

        for (int i = 0; i < list.size(); i++) {
            for (int j = 0; j < channel.size(); j++) {
                if (list.get(i).getIp().equals(channel.get(j).get("ip"))) {
                    channel.get(j).put("id", list.get(i).getId());
                    channel.get(j).put("factory", list.get(i).getFactory());
                }
            }
        }

        nvrService.addChannelNumber(channel,nvrId);
    }


    /**
     * 导入excel
     * @param file 文件数据
     * @param fileType 类型：如xlsx
     * @param orgid 组织机构id
     * @return
     */
    @RequestMapping(value="/importFile")
    public String importFile(MultipartFile file, String fileType, HttpServletRequest request,String orgid){

        String[] titleArr = {"NVR名称","NVR别名","所属厂商","NVR型号","NVR类型","NVRIP","NVR网关地址","NVR子网掩码","NVR账号","NVR密码","NVR端口","NVR管理员","安装位置","备注"};//第一行的title
        boolean[] emptyArr = {true   ,  false  ,  false , true  ,  false   ,  false   ,    true     ,    true   ,   false  , false   ,false   ,   true,   true ,   true};//指定列可为空，不可为空值为false.

        List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list

        String errormsg = "";
        try {
            errormsg = importService.importFile(uploadPath, file,fileType,request,titleArr,emptyArr,list);

            //这句放到页面判断--
            if (errormsg != null && !"".equals(errormsg)) {
                return errormsg;
            }
            //--

            //这句返回后台判断
            if (list.size()>0) {
            	errormsg = nvrService.importData(list,Integer.parseInt(orgid));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return errormsg;
    }
}
