package com.chinaitop.depot.basic.controller;

import com.chinaitop.depot.basic.model.MonitorCamera;
import com.chinaitop.depot.basic.model.MonitorCameraExample;
import com.chinaitop.depot.basic.model.MonitorPreset;
import com.chinaitop.depot.basic.model.MonitorPresetExample;
import com.chinaitop.depot.basic.service.MonitorCameraService;
import com.chinaitop.depot.basic.service.MonitorPresetService;
import com.fasterxml.jackson.databind.ObjectMapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 摄像头预置点操作类
 */
@RestController
@RequestMapping(value="preset")
@Api(value= "MonitorPresetController", description = "摄像头预置点操作类")
public class MonitorPresetController {

    @Resource
    private MonitorPresetService presetService;

    @Resource
    private MonitorCameraService cameraService;

    @RequestMapping(value="/getAllCamera", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="获取所有摄像头信息", notes = "获取所有摄像头信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "channelNumber", value = "通道号", paramType = "query")
    })
    public List<MonitorCamera> getAllCamera(Integer orgId) {
        MonitorCameraExample example = new MonitorCameraExample();
        MonitorCameraExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId.toString());
        List<MonitorCamera> list = cameraService.queryByExample(example);
        return list;
    }

    @RequestMapping(value="/queryPreset", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="根据nvrip和通道号获取相关预置点信息", notes = "根据nvrip和通道号获取相关预置点信息")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "nvrIp", value = "nvrIP地址", paramType = "query"),
		@ApiImplicitParam(name = "channelNumber", value = "通道号", paramType = "query")
	})
    public List<MonitorPreset> queryPreset(String nvrIp,String channelNumber) {
        MonitorPresetExample example = new MonitorPresetExample();
        MonitorPresetExample.Criteria criteria = example.createCriteria();
        criteria.andNvrIpEqualTo(nvrIp);
        criteria.andChannelNumberEqualTo(channelNumber);
        example.setOrderByClause("position");
        List<MonitorPreset> list = presetService.queryByExample(example);
        return list;
    }

    @RequestMapping(value="/removePreset", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="清除预置点", notes = "清除预置点")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "nvrIp", value = "nvrIP地址", paramType = "form"),
		@ApiImplicitParam(name = "channelNumber", value = "通道号", paramType = "form"),
		@ApiImplicitParam(name = "position", value = "预置点位置", paramType = "form")
	})
    public Map<String, Object> removePreset(String nvrIp,String channelNumber,String position){
        Map<String, Object> modelMap = new HashMap<>();
        MonitorPresetExample example = new MonitorPresetExample();
        MonitorPresetExample.Criteria criteria = example.createCriteria();
        criteria.andNvrIpEqualTo(nvrIp);
        criteria.andChannelNumberEqualTo(channelNumber);
        criteria.andPositionEqualTo(position);
        try {
            presetService.removePreset(example);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @RequestMapping(value="/addPreset", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="添加预置点", notes = "添加预置点")
    @ApiImplicitParams({
		@ApiImplicitParam(name = "presetJson", value = "预置点数据", paramType = "form")
	})
    public Map<String, Object> addPreset(String presetJson){
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        MonitorPreset monitorpreset = null;
        try {
            monitorpreset = (MonitorPreset)mapper.readValue(presetJson, MonitorPreset.class);
            presetService.addPreset(monitorpreset);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
}
