package com.chinaitop.depot.basic.service.impl;

import com.chinaitop.depot.basic.mapper.MonitorNvrMapper;
import com.chinaitop.depot.basic.model.MonitorNvr;
import com.chinaitop.depot.basic.model.MonitorNvrExample;
import com.chinaitop.depot.basic.service.MonitorNvrService;
import com.chinaitop.depot.utils.ParameterUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class MonitorNvrServiceImpl implements MonitorNvrService {

    @Resource
    private MonitorNvrMapper monitorNvrMapper;

    //条件查询nvr列表
    @Override
    public List<MonitorNvr> selectByExample(MonitorNvrExample example) {
        return monitorNvrMapper.selectByExample(example);
    }
    //保存数据
    @Override
    public void save(MonitorNvr monitorNvr) {
		if (ParameterUtil.isnull(monitorNvr.getId())){
			if(ParameterUtil.isnull(monitorNvr.getQuantity())){
				monitorNvr.setQuantity("0");//默认camera数量为0个
			}
			monitorNvrMapper.insert(monitorNvr);//新增数据
		}
        else{
            monitorNvrMapper.updateByPrimaryKeySelective(monitorNvr);//修改数据
        }
    }

    @Override
    @Transactional
    public void remove(int id) {
        //逻辑删除数据
        MonitorNvr monitorNvr = new MonitorNvr();
        monitorNvr.setId(id);
        monitorNvr.setDeleteMark("0");
        monitorNvrMapper.updateByPrimaryKeySelective(monitorNvr);
        //修改删除状态之后，在nvr-camera关系表中根据nvrid进行物力删除操作
        monitorNvrMapper.deleteNvrCameraByNVRID(id);
    }

    @Override
    public MonitorNvr loadDataById(int id) {
        return monitorNvrMapper.selectByPrimaryKey(id);
    }

    @Override
    public List<Map<String,Object>> getThroughByNVRId(Integer nvrId) {
        List<Map<String,Object>> retMap = monitorNvrMapper.getThroughByNVRId(nvrId);
        return retMap;
    }

    @Override
    @Transactional(readOnly = false)
    public void addChannelNumber(List<Map<String, Object>> channel, String nvrId) {
        Integer nvrIdint =  Integer.parseInt(nvrId);
        //修改nvr里边的摄像头数量
        MonitorNvr monitorNvr = new MonitorNvr();
        monitorNvr.setId(nvrIdint);
        monitorNvr.setQuantity(String.valueOf(channel.size()));
        monitorNvrMapper.updateByPrimaryKeySelective(monitorNvr);
        //删除通道号表的nvr数据
        monitorNvrMapper.deleteNvrCameraByNVRID(nvrIdint);
        //新增通道号表里边的数据
        String channelDate = "";
        for(int i=0;i<channel.size();i++){
            String tdh = String.valueOf(channel.get(i).get("tdh"));

            try {
                tdh = ParameterUtil.isequal(channel.get(i).get("factory"),"200")?String.valueOf(Integer.parseInt(tdh)+32):String.valueOf(Integer.valueOf(tdh)+1);
            } catch (Exception e) {

            }
            channelDate+= "("+nvrIdint+","+channel.get(i).get("id")+","+tdh+"),";
        }

        Map<String, Object> channelMap = new HashMap<String, Object>();
        channelMap.put("channel",channelDate.substring(0,channelDate.length()-1));

        monitorNvrMapper.insertChannel(channelMap);
    }

    /**
     * 导入
     * @param list
     */
    @Override
    public String importData(List<List<String>> list,Integer orgid) {
    	String msg = "";
        boolean value_flag = false;
    	int len = 0;
    	String ip = "([1-9]|[1-9]\\d|1\\d{2}|2[0-4]\\d|25[0-5])(\\.(\\d|[1-9]\\d|1\\d{2}|2[0-4]\\d|25[0-5])){3}";
    	
        StringBuilder sql = new StringBuilder();
        sql.append("");
        for (int i = 0; i < list.size(); i++) {
            List<String> revList = list.get(i);
            sql.append("(");
            sql.append("'"+orgid.toString()+"',");
            for (int j = 0; j < revList.size(); j++) {

            	switch(j) {
	            	case 0:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 20) {
	                			msg = "第 "+(i+1)+" 行第 1 列的值的长度不能超过20！";
	                			return msg;
	                		}
	            		}
	            		//sql.append("\""+getVal(j,revList)+"\"");
	            		break;
	            	case 1:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 50) {
	                			msg = "第 "+(i+1)+" 行第 2 列的值的长度不能超过50！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 2:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 20) {
	                			msg = "第 "+(i+1)+" 行第 3 列的值的长度不能超过20！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 3:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 30) {
	                			msg = "第 "+(i+1)+" 行第 4 列的值的长度不能超过30！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 4:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 10) {
	                			msg = "第 "+(i+1)+" 行第 5 列的值的长度不能超过10！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 5:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			value_flag = revList.get(j).matches(ip);
	                		if (!value_flag) {
	                			msg = "第 "+(i+1)+" 行的第 6 列的值不符合IP规范！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 6:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 100) {
	                			msg = "第 "+(i+1)+" 行第 7 列的值的长度不能超过100！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 7:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 50) {
	                			msg = "第 "+(i+1)+" 行第 8 列的值的长度不能超过50！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 8:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 30) {
	                			msg = "第 "+(i+1)+" 行第 9 列的值的长度不能超过30！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 9:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 30) {
	                			msg = "第 "+(i+1)+" 行第 10 列的值的长度不能超过30！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 10:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 30) {
	                			msg = "第 "+(i+1)+" 行第 11 列的值的长度不能超过30！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 11:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 30) {
	                			msg = "第 "+(i+1)+" 行第 12 列的值的长度不能超过30！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 12:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 100) {
	                			msg = "第 "+(i+1)+" 行第 13 列的值的长度不能超过100！";
	                			return msg;
	                		}
	            		}
	            		break;
	            	case 13:
	            		if (revList.get(j) != null && !"".equals(revList.get(j))) {
	            			len = revList.get(j).length();
	                		if (len > 200) {
	                			msg = "第 "+(i+1)+" 行第 14 列的值的长度不能超过200！";
	                			return msg;
	                		}
	            		}
	            		break;
            		default:
            			break;
            	}

            	sql.append("\""+getVal(j,revList)+"\"");
                if (j != revList.size()-1){
                    sql.append(",");
                }
            }
            sql.append(")");
            if (i != list.size()-1){
                sql.append(",");
            }
        }

        System.out.println(sql.toString());
        Map<String,String> map = new HashMap<String, String>();
        map.put("sql",sql.toString());
        monitorNvrMapper.importData(map);
        
        return msg;
    }

    //获取指标对应的值
    private String getVal(int index,List<String> revList){
        //该位置为excel中需要变为对应id的数据

        if(index == 2){//factory
            return NvrFactoryEnum.getIdByFactoryName(revList.get(index));
        }
        if (index == 4){//type,枪机，球机
            return NvrTypeEnum.getIdByType(revList.get(index));
        }
        return revList.get(index);
    }
}

enum NvrFactoryEnum{
    HC("1","海康"),DH("2","大华"),OTHER("3","其他");

    private String id;
    private String factoryName;

    NvrFactoryEnum(String id,String factoryName){
        this.id = id;
        this.factoryName = factoryName;
    }

    public static String getIdByFactoryName(String factoryName){
        for (NvrFactoryEnum n: NvrFactoryEnum.values()) {
            if(factoryName.contains(n.factoryName)){
                return n.id;
            }
        }
        return null;
    }

}
enum NvrTypeEnum{
    QIANG("2","枪机"),QIU("1","球机"),OTHER("3","其他");

    private String id;
    private String type;

    NvrTypeEnum(String id,String type){
        this.id = id;
        this.type = type;
    }

    public static String getIdByType(String type){
        for (NvrTypeEnum n: NvrTypeEnum.values()) {
            if(type.contains(n.type)){
                return n.id;
            }
        }
        return null;
    }

}