package com.chinaitop.depot.hk.constant;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 取流协议（应用层协议）
 * hik”:HIK私有协议，使用视频SDK进行播放时，传入此类型；
 * “rtsp”:RTSP协议；
 * “rtmp”:RTMP协议（RTMP协议只支持海康SDK协议、EHOME协议、ONVIF协议接入的设备；只支持H264视频编码和AAC音频编码）；
 * “hls”:HLS协议（HLS协议只支持海康SDK协议、EHOME协议、ONVIF协议接入的设备；只支持H264视频编码和AAC音频编码）；
 * “ws”:Websocket协议（一般用于H5视频播放器取流播放）。
 * 参数不填，默认为HIK协议
 *
 * @author ybw
 * @version V1.0
 * @className HkProtocolEnum
 * @date 2024/7/24
 **/
@AllArgsConstructor
@Getter
public enum HkProtocolEnum {

    /**
     * hik”:HIK私有协议，使用视频SDK进行播放时，传入此类型；
     *
     * @author: ybw
     * @date: 2024/7/24
     **/
    HIK("hik"),
    /**
     * “rtsp”:RTSP协议；
     *
     * @author: ybw
     * @date: 2024/7/24
     **/
    RTSP("rtsp"),
    /**
     * “rtmp”:RTMP协议（RTMP协议只支持海康SDK协议、EHOME协议、ONVIF协议接入的设备；只支持H264视频编码和AAC音频编码）；
     *
     * @author: ybw
     * @date: 2024/7/24
     **/
    RTMP("rtmp"),
    /**
     * “hls”:HLS协议（HLS协议只支持海康SDK协议、EHOME协议、ONVIF协议接入的设备；只支持H264视频编码和AAC音频编码）；
     *
     * @author: ybw
     * @date: 2024/7/24
     **/
    HLS("hls"),
    /**
     * “ws”:Websocket协议（一般用于H5视频播放器取流播放）。
     *
     * @author: ybw
     * @date: 2024/7/24
     **/
    WS("ws");

    private String name;
}
