package com.chinaitop.depot.hk.service;


import com.chinaitop.depot.hk.dto.req.*;
import com.chinaitop.depot.hk.dto.res.*;

/**
 * 海康
 *
 * @author ybw
 * @version V1.0
 * @className HkService
 * @date 2024/6/18
 **/
public interface HkService {
    //----------------------------------------资源目录-----------------------------------------------

    /**
     * 分页获取区域列表
     *
     * @param pageReqDTO
     * @methodName: getRegions
     * @return: com.ybw.dto.res.ResultResDTO<com.ybw.dto.res.PageResDTO < com.ybw.dto.res.RegionResDTO>>
     * @author: ybw
     * @date: 2024/6/19
     **/
    PageResDTO<RegionResDTO> getRegions(PageReqDTO pageReqDTO);

    /**
     * 分页获取监控点资源
     *
     * @param pageReqDTO
     * @methodName: getCameras
     * @return: com.ybw.dto.res.PageResDTO<com.ybw.dto.res.CamerasResDTO>
     * @author: ybw
     * @date: 2024/7/23
     **/
    PageResDTO<CamerasResDTO> getCameras(PageReqDTO pageReqDTO);
    //----------------------------------------视频应用服务-----------------------------------------------

    /**
     * 根据编号获取监控点详细信息
     *
     * @param cameraReqDTO
     * @methodName: getCamera
     * @return: com.ybw.dto.res.ResultResDTO<com.ybw.dto.res.RegionResDTO>
     * @author: ybw
     * @date: 2024/6/19
     **/
    CameraResDTO getCamera(CameraReqDTO cameraReqDTO);

    /**
     * 获取监控点预览取流 获取监控点预览取流  URLv2
     *
     * @param previewReqDTO
     * @methodName: s
     * @return: com.ybw.dto.res.ResultResDTO<com.ybw.dto.res.PreviewResDTO>
     * @author: ybw
     * @date: 2024/6/20
     **/
    PreviewResDTO previewURLs(PreviewReqDTO previewReqDTO);

    //----------------------------------------视频应用服务-录像-----------------------------------------------

    /**
     * 获取监控点回放取流URLv2
     *
     * @param playbackReqDTO
     * @methodName: playbackURLs
     * @return: com.ybw.dto.res.PlaybackResDTO
     * @author: ybw
     * @date: 2024/6/20
     **/
    PlaybackResDTO playbackURLs(PlaybackReqDTO playbackReqDTO);

    /**
     * 开始手动录像
     *
     * @param recordStartReqDTO
     * @methodName: recordStart
     * @return: com.ybw.dto.res.RecordStartResDTO
     * @author: ybw
     * @date: 2024/6/20
     **/
    RecordStartResDTO recordStart(RecordStartReqDTO recordStartReqDTO);

    /**
     * 停止手动录像
     *
     * @param recordStopReqDTO
     * @methodName: recordStop
     * @return: com.ybw.dto.res.RecordStartResDTO
     * @author: ybw
     * @date: 2024/6/20
     **/
    void recordStop(RecordStopReqDTO recordStopReqDTO);


    /**
     * 手动抓图
     *
     * @param captureReqDTO
     * @methodName: manualCapture
     * @return: com.ybw.dto.res.CaptureResDTO
     * @author: ybw
     * @date: 2024/6/20
     **/
    CaptureResDTO manualCapture(CaptureReqDTO captureReqDTO);

    //----------------------------------------视频应用服务-云台操作-----------------------------------------------

    /**
     * 云台控制
     *
     * @param controllerReqDTO
     * @methodName: controlling
     * @return: void
     * @author: ybw
     * @date: 2024/6/20
     **/
    void controlling(ControllerReqDTO controllerReqDTO);


    //----------------------------------------视频应用服务-预置点管理-----------------------------------------------

    /**
     * 查询预置点信息
     *
     * @param presetsSearchReqDTO
     * @methodName: searchPresets
     * @return: com.ybw.dto.res.PresetsSearchResDTO
     * @author: ybw
     * @date: 2024/8/2
     **/
//    PresetsSearchResDTO searchPresets(PresetsSearchReqDTO presetsSearchReqDTO);

    /**
     * 批量获取监控点的预置点信息
     *
     * @param presetsReqDTO
     * @methodName: getPresets
     * @return: com.ybw.dto.res.PresetsResDTO
     * @author: ybw
     * @date: 2024/8/2
     **/
    PresetsResDTO getPresets(PresetsReqDTO presetsReqDTO);
}
