package com.chinaitop.depot.hk.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.chinaitop.depot.hk.constant.ApiHkConstant;
import com.chinaitop.depot.hk.dto.req.*;
import com.chinaitop.depot.hk.dto.res.*;
import com.chinaitop.depot.hk.service.HkService;
import com.hikvision.artemis.sdk.ArtemisHttpUtil;
import com.hikvision.artemis.sdk.config.ArtemisConfig;
import com.hikvision.artemis.sdk.constant.ContentType;
import com.hikvision.artemis.sdk.constant.HttpSchema;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @author ybw
 * @version V1.0
 * @className HkServiceImpl
 * @date 2024/6/18
 **/
@Service
@Slf4j
public class HkServiceImpl implements HkService {

    @Resource
    private ArtemisConfig artemisConfig;

    @Override
    public PageResDTO<RegionResDTO> getRegions(PageReqDTO pageReqDTO) {
        try {
            Map<String, String> path = getPath(ApiHkConstant.API_HK_REGIONS);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(pageReqDTO), null, null, ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<PageResDTO<RegionResDTO>> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<PageResDTO<RegionResDTO>>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("getRegions error:", e);
        }
        return null;
    }

    @Override
    public PageResDTO<CamerasResDTO> getCameras(PageReqDTO pageReqDTO) {
        try {
            Map<String, String> path = getPath(ApiHkConstant.API_HK_CAMERAS);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(pageReqDTO), null, null, ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<PageResDTO<CamerasResDTO>> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<PageResDTO<CamerasResDTO>>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("getRegions error:", e);
        }
        return null;
    }

    /**
     * 获取接口地址
     *
     * @param api
     * @methodName: getPath
     * @return: java.util.Map<java.lang.String, java.lang.String>
     * @author: ybw
     * @date: 2024/6/19
     **/
    private Map<String, String> getPath(String api) {
        Map<String, String> path = new HashMap<String, String>(2) {
            {
                put(HttpSchema.HTTPS, api);
            }
        };
        return path;
    }

    @Override
    public CameraResDTO getCamera(CameraReqDTO cameraReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_CAMERA);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(cameraReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<CameraResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<CameraResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("getCamera error:", e);
        }
        return null;
    }

    @Override
    public PreviewResDTO previewURLs(PreviewReqDTO previewReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_PREVIEW_URL);
            //对象转换
            Preview2ReqDTO preview2ReqDTO = new Preview2ReqDTO(previewReqDTO);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(preview2ReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<PreviewResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<PreviewResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("previewURLs error:", e);
        }
        return null;
    }

    @Override
    public PlaybackResDTO playbackURLs(PlaybackReqDTO playbackReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_PLAYBACK_URL);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(playbackReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<PlaybackResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<PlaybackResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("previewURLs error:", e);
        }
        return null;
    }

    @Override
    public RecordStartResDTO recordStart(RecordStartReqDTO recordStartReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_RECORD_START);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(recordStartReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<RecordStartResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<RecordStartResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("recordStart error:", e);
        }
        return null;
    }

    @Override
    public void recordStop(RecordStopReqDTO recordStopReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_RECORD_STOP);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(recordStopReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            log.info("{}", result);
        } catch (Exception e) {
            log.error("recordStop error:", e);
        }
    }

    @Override
    public CaptureResDTO manualCapture(CaptureReqDTO captureReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_MANUAL_CAPTURE);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(captureReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<CaptureResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<CaptureResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("manualCapture error:", e);
        }
        return null;
    }

    @Override
    public void controlling(ControllerReqDTO controllerReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_PTZS_CONTROLLING);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(controllerReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            log.info("{}", JSON.toJSONString(result));
        } catch (Exception e) {
            log.error("controlling error:", e);
        }
    }

//    @Override
//    public PresetsSearchResDTO searchPresets(PresetsSearchReqDTO presetsSearchReqDTO) {
//        try {
//            // 接口地址
//            Map<String, String> path = getPath(ApiHkConstant.API_HK_PRESETS_SEARCH);
//            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(presetsSearchReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
//            log.info("result:{}",result);
//            ResultResDTO<PresetsSearchResDTO> resultResDTO = JSONObject.parseObject(
//                    result,
//                    new TypeReference<ResultResDTO<PresetsSearchResDTO>>() {
//                    }
//            );
//            log.info("{}", JSON.toJSONString(resultResDTO));
//            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
//                return resultResDTO.getData();
//            }
//        } catch (Exception e) {
//            log.error("searchPresets error:", e);
//        }
//        return null;
//    }

    @Override
    public PresetsResDTO getPresets(PresetsReqDTO presetsReqDTO) {
        try {
            // 接口地址
            Map<String, String> path = getPath(ApiHkConstant.API_HK_PRESETS_GET);
            String result = ArtemisHttpUtil.doPostStringArtemis(artemisConfig, path, JSON.toJSONString(presetsReqDTO), null, null,  ContentType.CONTENT_TYPE_JSON);
            ResultResDTO<PresetsResDTO> resultResDTO = JSONObject.parseObject(
                    result,
                    new TypeReference<ResultResDTO<PresetsResDTO>>() {
                    }
            );
            log.info("{}", JSON.toJSONString(resultResDTO));
            if (ApiHkConstant.Code.SUCCESS.equals(resultResDTO.getCode())) {
                return resultResDTO.getData();
            }
        } catch (Exception e) {
            log.error("getPresets error:", e);
        }
        return null;
    }
}
