package com.chinaitop.depot.log.controller;

import com.chinaitop.depot.basic.model.MonitorCamera;
import com.chinaitop.depot.log.model.LogDepot;
import com.chinaitop.depot.log.model.LogDepotExample;
import com.chinaitop.depot.log.model.LogDepotExample.Criteria;
import com.chinaitop.depot.log.service.LogService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;

/**
 * @auther mafy
 * @createtime 2018/1/2 0002
 */
@RestController
@RequestMapping(value = "/Log")
public class LogController {

    @Resource
    private LogService logService;

    /**
     * 获取日志列表
     * @param pageNum 页码
     * @param pageSize 每页条数
     * @param ip 操作IP
     * @param operaMan 操作人
     * @param operaDepartment 所属机构
     * @param level 等级
     * @return
     */
    @RequestMapping(value = "/getLogList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查找摄像头信息", notes = "查找摄像头信息，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "ip", value = "操作IP", paramType = "query"),
		@ApiImplicitParam(name = "operaMan", value = "操作人", paramType = "query"),
		@ApiImplicitParam(name = "operaDepartment", value = "所属机构", paramType = "query"),
		@ApiImplicitParam(name = "level", value = "等级", paramType = "query")/*,
        @ApiImplicitParam(name="orgId", value="组织机构id", paramType="query")*/
	})
    public PageInfo<LogDepot> getLogList(Integer pageNum, Integer pageSize,String ip,String operaMan,
    		String operaDepartment,String level,Integer orgId){
    	LogDepotExample example = new LogDepotExample();
    	Criteria criteria = example.createCriteria();
    	if (ParameterUtil.isnotnull(ip)) {
    		criteria.andOperaIpLike("%"+ip+"%");
    	}
    	if (ParameterUtil.isnotnull(operaMan)) {
    		criteria.andOperaManLike("%"+operaMan+"%");
    	}
    	if (ParameterUtil.isnotnull(operaDepartment)) {
    		criteria.andOperaDepartmentLike("%"+operaDepartment+"%");
    	}
    	if (ParameterUtil.isnotnull(level)) {
    		criteria.andLevelEqualTo(level);
    	}
    	if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
    	List<LogDepot> list = logService.queryByExample(example);
    	PageInfo<LogDepot> pageInfo = new PageInfo<LogDepot>(list);
        return pageInfo;
    }
}
