package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.monitor.model.MonitorAlarmPhone;
import com.chinaitop.depot.monitor.model.MonitorAlarmPhoneExample;
import com.chinaitop.depot.monitor.service.AlarmSettingService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 报警的配置类
 */
@RestController
@RequestMapping(value = "/alarmSetting")
@Api(description = "报警的配置类")
public class AlarmSettingController {

    @Resource
    private AlarmSettingService alarmSettingService;

    @RequestMapping(value="/getAlarmPhone", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="报警配置信息", notes = "报警配置信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "detectionType", value = "检测类型", paramType = "query"),
            @ApiImplicitParam(name = "alarmRole", value = "角色", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID",paramType = "form")
    })
    public PageInfo<MonitorAlarmPhone> getAlarmPhone(Integer pageNum, Integer pageSize, String detectionType, String alarmRole,Integer orgId) {
        MonitorAlarmPhoneExample example = new MonitorAlarmPhoneExample();
        MonitorAlarmPhoneExample.Criteria criteria = example.createCriteria();

        if (ParameterUtil.isnotnull(alarmRole)) {
            criteria.andAlarmRoleLike("%" + alarmRole + "%");
        }
        criteria.andDetectionTypeEqualTo(detectionType);
        criteria.andOrgIdEqualTo(orgId);

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<MonitorAlarmPhone> list = alarmSettingService.getAlarmPhone(example);
        PageInfo<MonitorAlarmPhone> pageInfo = new PageInfo<MonitorAlarmPhone>(list);
        return pageInfo;
    }

    @RequestMapping(value="/saveAlarmPhone", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存报警配置信息", notes = "保存报警信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "alarmJson", value = "报警配置信息",paramType = "form"),
            @ApiImplicitParam(name = "orgid", value = "组织机构ID",paramType = "form")
    })
    public Map<String, Object> saveAlarmPhone(String alarmJson,Integer orgid) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        MonitorAlarmPhone camera = (MonitorAlarmPhone)mapper.readValue(alarmJson, MonitorAlarmPhone.class);
        camera.setOrgId(orgid);//添加组织
        alarmSettingService.saveAlarmPhone(camera);
        modelMap.put("status", "success");
        return modelMap;
    }

    @RequestMapping(value="/deleteAlarmPhone", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除报警信息", notes = "删除报警信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "alarmId", value="需要删除的报警信息ID", paramType = "form")
    })
    public Map<String, Object> deleteAlarmPhone(String alarmId){
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            alarmSettingService.deleteAlarmPhone(Integer.valueOf(alarmId));
            modelMap.put("status", "success");
        }catch (Exception e){
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @RequestMapping(value="/getAllAlarmPhone", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="报警信息",notes = "查询报警信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value="组织机构ID", paramType = "query")
    })
    public List<MonitorAlarmPhone> getAllAlarmPhone(Integer orgId) {
        return alarmSettingService.getAllAlarmPhone(orgId);
    }
}
