package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.monitor.model.MonitorSettingPath;
import com.chinaitop.depot.monitor.model.MonitorSettingPathExample;
import com.chinaitop.depot.monitor.service.CameraSettingService;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/25 0025
 * 安防的配置类
 */
@RestController
@RequestMapping(value = "/cameraSetting")
@Api(description = "安防的配置类")
public class CameraSettingController{

    @Resource
    private CameraSettingService cameraSettingService;

    @RequestMapping(value = "/getAllPath", method = RequestMethod.GET)
    @ApiOperation(value="查询配置信息", notes = "获取抓图、录像的保存路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public MonitorSettingPath getAllPath(Integer orgId){
        MonitorSettingPathExample example = new MonitorSettingPathExample();
        MonitorSettingPathExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        return cameraSettingService.getAllPath(example);
    }

    @RequestMapping(value = "/savePath", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存配置路径", notes = "设置抓图、录像的保存路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pathJson", value = "保存的数据", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "form")
    })
    public Map<String,String>  savePath(String pathJson,Integer orgId){
        Map<String,String> map = new HashMap<String,String>();
        ObjectMapper mapper = new ObjectMapper();
        try {
            MonitorSettingPath monitorSettingPath = (MonitorSettingPath) mapper.readValue(pathJson, MonitorSettingPath.class);
            monitorSettingPath.setOrgId(orgId);
            cameraSettingService.setAllPath(monitorSettingPath);
            map.put("status","success");
        } catch (IOException e) {
            e.printStackTrace();
            map.put("status","success");
        }
        return map;
    }

}
