package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.monitor.model.Group;
import com.chinaitop.depot.monitor.model.GroupExample;
import com.chinaitop.depot.monitor.service.GroupService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/22 0022
 * 实现分组的增删改和分组摄像头的关系的处理
 */
@RestController
@RequestMapping(value = "/group")
@Api(description = "分组调用类")
public class GroupController {

    @Resource
    private GroupService groupService;

    @RequestMapping(value = "/getGroupList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="分组列表", notes = "获取分组列表-分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<Group> getGroupList(Integer pageNum, Integer pageSize,Integer orgId){
        GroupExample example = new GroupExample();
        GroupExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);

        PageHelper.startPage(pageNum, pageSize);
        List<Group> list = groupService.selectByExampleForPlan(example);
        PageInfo<Group> pageInfo = new PageInfo<Group>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getGroupListNoPage", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="分组列表全", notes = "获取分组列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public List<Group> getGroupListNoPage(Integer orgId){
        GroupExample example = new GroupExample();
        GroupExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        List<Group> groupList = groupService.selectByExampleForPlan(example);
        return groupList;
    }

    @RequestMapping(value = "/groupSave", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "分组保存", notes = "分组保存数据信息!")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "groupJson", value = "分组需要保存的json数据",paramType = "form"),
            @ApiImplicitParam(name = "CameraId", value = "分组保存的摄像头id",paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID",paramType = "from")
    })
    public Map<String,Object> groupSave(String groupJson,String CameraId,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
            Group group = (Group) mapper.readValue(groupJson, Group.class);
            group.setOrgId(orgId);//组织机构
            if (group.getId() == null) {
                groupService.add(group);

                Integer groupId = getGroupIdLast(orgId);
                String[] ids = CameraId.split(",");
                for (int i = 0; i < ids.length; i++) {
                    editGroupCamera(groupId,Integer.parseInt(ids[i]),1);
                }

            } else {
                groupService.update(group);
                String[] ids = CameraId.split(",");
                editGroupCamera(group.getId(),null,3);
                for (int i = 0; i < ids.length; i++) {
                    editGroupCamera(group.getId(),Integer.parseInt(ids[i]),1);
                }
            }

        } catch (IOException e) {
            e.printStackTrace();
        }

        modelMap.put("status", "success");
        return modelMap;
    }

    @RequestMapping(value = "removebyid", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "删除分组数据", notes = "根据分组id移除数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "groupid", value = "分组ID" , paramType = "form")
    })
    public Map<String,String> removebyid(Integer groupid){
        Map<String,String> map = new HashMap<String, String>();
        groupService.removebyid(groupid);
        return null;
    }

    @RequestMapping(value = "queryCameraForGroup", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询分组摄像头",notes = "查询不在当前分组的摄像头")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "groupid", value = "分组ID", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public List<Map<String,Object>> queryCameraForGroup(String groupid,Integer orgId){
        Map<String,Object> map = new HashMap<String, Object>();
        map.put("groupid",Integer.parseInt(groupid));
        map.put("orgid",orgId.toString());

        return ParameterUtil.slashCapitals(groupService.queryCameraForGroup(map));
    }

    @RequestMapping(value = "editGroupCamera", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "编辑分组内摄像头",notes = "编辑分组内摄像头")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "groupid", value = "分组ID", paramType = "form"),
            @ApiImplicitParam(name = "cameraid", value = "摄像头ID", paramType = "form"),
            @ApiImplicitParam(name = "type", value = "1是添加，0是删除", paramType = "form")
    })
    public Map<String,String> editGroupCamera(Integer groupid,Integer cameraid,Integer type){
        Map<String,String > map = new HashMap<String, String>();
        groupService.editGroupCamera(groupid,cameraid,type);
        map.put("status","success");
        return map;
    }


    //获取最后一个分组id
    private Integer getGroupIdLast(Integer orgId){
        Map<String,Object > map = new HashMap<String, Object>();
        map.put("orgid",orgId.toString());
        int a = Integer.parseInt(groupService.getGroupIdLast(map).get("id").toString());
        return a;
    }

}
