package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.monitor.model.MonitorAlarm;
import com.chinaitop.depot.monitor.model.MonitorAlarmExample;
import com.chinaitop.depot.monitor.model.MonitorAlarmType;
import com.chinaitop.depot.monitor.model.MonitorAlarmTypeExample;
import com.chinaitop.depot.monitor.service.MonitorAlarmService;
import com.chinaitop.depot.monitor.util.SendMessagePT.SendMessagePT;
import com.chinaitop.depot.monitor.util.SendMessagePT.SmsDataVO;
import com.chinaitop.depot.utils.ParameterUtil;
import com.chinaitop.depot.utils.RedisUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 安防警报操作类
 */
@RestController
@RequestMapping(value="alarm")
@Api(description = "安防警报操作类")
public class MonitorAlarmController {

    @Resource
    private MonitorAlarmService alarmService;
    
    @Autowired
	private RedisUtil redisUtil;

    @RequestMapping(value="/getAlarm", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="警告信息", notes = "查找警告信息-分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "alarmType", value = "警报类型 0：质量检测，1：行为分析检测", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<MonitorAlarm> getAlarm(Integer pageNum, Integer pageSize, String alarmType,Integer orgId,String queryCriteria) {
        MonitorAlarmExample example = new MonitorAlarmExample();
        MonitorAlarmExample.Criteria criteria = example.createCriteria();
//        criteria.andOrgIdEqualTo(orginfo.getOrgId());
        if (ParameterUtil.isnotnull(alarmType))
            criteria.andAlarmTypeEqualTo(alarmType);
        if("currentMonth".equals(queryCriteria)) {//查询当前月份数据
        	SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"); 
        	Calendar cale = Calendar.getInstance();
        	int year = cale.get(Calendar.YEAR);  
            int month = cale.get(Calendar.MONTH);
        	Calendar cal = Calendar.getInstance();
            cal.set(Calendar.YEAR,year);
            cal.set(Calendar.MONTH, month);
            //获取某月最小天数
            int firstDay = cal.getActualMinimum(Calendar.DAY_OF_MONTH);
            cal.set(Calendar.DAY_OF_MONTH, firstDay);
            cal.set(Calendar.HOUR_OF_DAY, 0);
            cal.set(Calendar.MINUTE, 0);
            cal.set(Calendar.SECOND, 0);
            String firstDayOfMonth = format.format(cal.getTime());
            
            Calendar cals = Calendar.getInstance();
            cals.set(Calendar.YEAR,year);
            cals.set(Calendar.MONTH, month);
            //获取某月最大天数
            int lastDay = cals.getActualMaximum(Calendar.DAY_OF_MONTH);
            cals.set(Calendar.DAY_OF_MONTH, lastDay);
            cals.set(Calendar.HOUR_OF_DAY, 23);
            cals.set(Calendar.MINUTE, 59);
            cals.set(Calendar.SECOND, 59);
            String lastDayOfMonth = format.format(cals.getTime());
            try {
            	criteria.andAlarmTimeBetween(format.parse(firstDayOfMonth), format.parse(lastDayOfMonth));
			} catch (Exception e) {
				e.printStackTrace();
			}
        }
        PageHelper.startPage(pageNum, pageSize);
        List<MonitorAlarm> list = alarmService.queryByExample(example);
        PageInfo<MonitorAlarm> pageInfo = new PageInfo<MonitorAlarm>(list);
        return pageInfo;
    }

    @RequestMapping(value="/edit", method = RequestMethod.GET)
    @ApiOperation(value = "详细警告信息", notes = "根据编号查找详细警告信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "报警ID", paramType = "query")
    })
    public MonitorAlarm edit(Integer id) {
        MonitorAlarm alarm = new MonitorAlarm();
        if (id != null) {
            alarm = alarmService.findById(id);
        }
        return alarm;
    }

    @RequestMapping(value="/saveAlarm", method = RequestMethod.POST)
    @ApiOperation(value = "保存警告信息", notes = "保存警告信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "alarmName", value = "警报名称 0：质量检测，1：行为分析检测", paramType = "form"),
            @ApiImplicitParam(name = "alarmType", value = "警报类型 0-短信报警，1-系统报警", paramType = "form"),
            @ApiImplicitParam(name = "imgPath", value = "图片路径", paramType = "form"),
            @ApiImplicitParam(name = "cameraId", value = "摄像头ID", paramType = "form"),
            @ApiImplicitParam(name = "alarmGrade", value = "报警等级：1：低级，2中级，3高级", paramType = "form"),
            @ApiImplicitParam(name = "alarmContent", value = "警报内容", paramType = "form"),
            @ApiImplicitParam(name = "orgid", value = "组织机构ID", paramType = "form")
    })
    public void saveAlarm(String alarmName,String alarmType,String imgPath,String cameraId, String alarmGrade,String alarmContent,Integer orgid){
        MonitorAlarm alarm = new MonitorAlarm();
        alarm.setAlarmName(alarmName);
        alarm.setAlarmType(alarmType);
        alarm.setImgPath(imgPath);
        alarm.setCameraId(Integer.valueOf(cameraId));
        alarm.setAlarmGrade(alarmGrade);
        alarm.setAlarmContent(alarmContent);
        alarm.setOrgId(orgid);
        alarm.setAlarmTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改时间
        alarmService.addAlarm(alarm);
    }

    @RequestMapping(value="/getAlarmType", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "报警设置信息", notes = "获取报警设置信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public List<MonitorAlarmType> getAlarmType(Integer orgId) {
        MonitorAlarmTypeExample example = new MonitorAlarmTypeExample();
        MonitorAlarmTypeExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        List<MonitorAlarmType> list = alarmService.getAlarmType(example);
        return list;
    }

    @RequestMapping(value="/saveAlarmType", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "第一次保存报警设置", notes = "第一次保存报警设置信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "alarmJson",value = "第一次保存报警信息",paramType = "form"),
            @ApiImplicitParam(name = "orgId",value = "组织机构ID",paramType = "form")
    })
    public Map<String, Object> saveAlarmType(String alarmJson,Integer orgId) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            String newAlarmJson = alarmJson.replace("false","0");
            newAlarmJson = newAlarmJson.replace("true","1");
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            List<String> alarmList = Arrays.asList(newAlarmJson.split("\\},\\{"));
            MonitorAlarmType alarm = (MonitorAlarmType)mapper.readValue(alarmList.get(0).substring(1) + "}", MonitorAlarmType.class);
            alarm.setOrgId(orgId);
            alarmService.addAlarmType(alarm);

            alarm = (MonitorAlarmType)mapper.readValue("{" + alarmList.get(1), MonitorAlarmType.class);
            alarm.setOrgId(orgId);
            alarmService.addAlarmType(alarm);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    @RequestMapping(value="/updateAlarmType", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "修改报警设置", notes = "修改报警设置信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "alarmJson",value = "修改报警信息",paramType = "form"),
            @ApiImplicitParam(name = "orgId",value = "组织机构ID",paramType = "form")
    })
    public Map<String, Object> updateAlarmType(String alarmJson,Integer orgId) throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            String newAlarmJson = alarmJson.replace("false","0");
            newAlarmJson = newAlarmJson.replace("true","1");
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            List<String> alarmList = Arrays.asList(newAlarmJson.split("\\},\\{"));
            MonitorAlarmType alarm = (MonitorAlarmType)mapper.readValue(alarmList.get(0).substring(1) + "}", MonitorAlarmType.class);
            alarm.setOrgId(orgId);
            alarmService.update(alarm);

            alarm = (MonitorAlarmType)mapper.readValue("{" + alarmList.get(1), MonitorAlarmType.class);
            alarm.setOrgId(orgId);
            alarmService.update(alarm);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

	@RequestMapping(value="/sendMsg", method = RequestMethod.POST)
	@ApiOperation(value="用户登录", notes = "用户登录")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "phoneNumber", value = "手机号", paramType = "form")
	})
	public Map<String, Object> sendMsg(String phoneNumber) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		modelMap.put("status", false);
		modelMap.put("success", "发送失败！");
		SendMessagePT sendMessagePT = new SendMessagePT();//--短信平台
		String msgCode = ParameterUtil.randomCode(6);//获取6位随机数
		//发送短信
		try {
			SmsDataVO smsDataVO = new SmsDataVO();
          	smsDataVO.setSdst(phoneNumber);
          	smsDataVO.setSmsg("验证码为："+msgCode+" (有效时间5分钟)");
          	sendMessagePT.sendingSMS(smsDataVO);
          	redisUtil.set(phoneNumber, msgCode);//验证码存redis中
    		//倒计时5分钟，删除redis中的验证码信息
    		final Timer timer=new Timer();
    		timer.schedule(new TimerTask() {
    	        @Override
    	        public void run() {
    	        	redisUtil.del(phoneNumber);
    	        	timer.cancel();
    	        }
    	    },5*60*1000);
          	modelMap.put("status", true);
          	modelMap.put("success", "发送成功！");
		} catch (Exception e) {
			e.printStackTrace();
		}
		return modelMap;
	}	
}
