package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.hk.dto.req.CaptureReqDTO;
import com.chinaitop.depot.hk.dto.req.ControllerReqDTO;
import com.chinaitop.depot.hk.dto.req.PlaybackReqDTO;
import com.chinaitop.depot.hk.dto.req.PresetsReqDTO;
import com.chinaitop.depot.hk.dto.req.PreviewReqDTO;
import com.chinaitop.depot.hk.dto.req.RecordStartReqDTO;
import com.chinaitop.depot.hk.dto.req.RecordStopReqDTO;
import com.chinaitop.depot.hk.dto.res.CaptureResDTO;
import com.chinaitop.depot.hk.dto.res.PlaybackResDTO;
import com.chinaitop.depot.hk.dto.res.PresetsResDTO;
import com.chinaitop.depot.hk.dto.res.PreviewResDTO;
import com.chinaitop.depot.hk.dto.res.RecordStartResDTO;
import com.chinaitop.depot.hk.service.HkService;
import com.chinaitop.depot.monitor.model.CameraCapture;
import com.chinaitop.depot.monitor.model.CameraRecord;
import com.chinaitop.depot.monitor.service.CameraCaptureService;
import com.chinaitop.depot.monitor.service.CameraRecordService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.io.IOException;

import javax.annotation.Resource;

/**
 * 视频预览回放
 * 
 * 预览---开始手动录像---停止手动录像----回放--手动抓图--云台控制
 */
@RestController
@RequestMapping(value = "/previewPlayback")
@Api(description = "预览回放")
public class PreviewPlaybackController {

    @Resource
    private HkService hkService;
    
    @Resource
    private CameraCaptureService cameraCaptureService;
    
    @Resource
    private CameraRecordService cameraRecordService;

    @Resource
    private RestTemplate restTemplate;

    @Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;
    
    /**
     * 摄像头预览
     * @param previewReqDTO
     * @return
     */
    @RequestMapping(value="/getPreview", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="预览", notes = "预览")
    public PreviewResDTO getAlarmPhone(PreviewReqDTO previewReqDTO) {
        return hkService.previewURLs(previewReqDTO);
    }
    
    
    /**
     * 摄像头回放
     * @param playbackReqDTO
     * @return
     */
    @RequestMapping(value="/getPlayback", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="回放", notes = "回放")
    public PlaybackResDTO getPlayback(@RequestBody PlaybackReqDTO playbackReqDTO) {
        return hkService.playbackURLs(playbackReqDTO);
    }

    
    /**
     * 开始手动录像
     * @param recordStartReqDTO
     * @return
     * @throws IOException 
     * @throws JsonMappingException 
     * @throws JsonParseException 
     */
    @RequestMapping(value="/recordStart", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="开始手动录像", notes = "开始手动录像")
    public RecordStartResDTO recordStart(String recordStartReqDTOJson, String cameraRecordJson) throws Exception {
    	
        
        // JSON字符串转对象
        ObjectMapper mapper1 = new ObjectMapper();
        CameraRecord cameraRecord = (CameraRecord)mapper1.readValue(cameraRecordJson, CameraRecord.class);
        
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        RecordStartReqDTO recordStartReqDTO = (RecordStartReqDTO)mapper.readValue(recordStartReqDTOJson, RecordStartReqDTO.class);
        
    	
    	RecordStartResDTO recordStartResDTO = hkService.recordStart(recordStartReqDTO);
    	
    	cameraRecord.setTaskId(recordStartResDTO.getTaskID());
    	cameraRecordService.save(cameraRecord);
    	
        return recordStartResDTO;
    }
    
    /**
     * 停止手动录像
     * @param recordStopReqDTO
     */
    @RequestMapping(value="/recordStop", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="停止手动录像", notes = "停止手动录像")
    public void recordStop(RecordStopReqDTO recordStopReqDTO) {
         hkService.recordStop(recordStopReqDTO);
    }
    
    
    /**
     * 手动抓图
     * @param captureReqDTO
     * @throws IOException 
     * @throws JsonMappingException 
     * @throws JsonParseException 
     */
    @RequestMapping(value="/manualCapture", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="手动抓图", notes = "手动抓图")
    public String manualCapture(String captureReqDTOJson, String cameraCaptureJson) throws Exception {
    	
    	
    	// JSON字符串转对象
        ObjectMapper mapper1 = new ObjectMapper();
        CaptureReqDTO captureReqDTO = (CaptureReqDTO)mapper1.readValue(captureReqDTOJson, CaptureReqDTO.class);
        
        // JSON字符串转对象
        /*ObjectMapper mapper = new ObjectMapper();
        CameraCapture cameraCapture = (CameraCapture)mapper.readValue(cameraCaptureJson, CameraCapture.class);*/
        
    	CaptureResDTO captureResDTO = hkService.manualCapture(captureReqDTO);
         
    	
         //加到表里
    	/*CameraCapture cameraCapture1 = cameraCaptureService.save(cameraCapture,captureResDTO.getPicUrl());
         if(cameraCapture1.getId()>0){
        	 //传到国家局
        	 this.gjjjk(cameraCapture1.getId(), Integer.valueOf(cameraCapture1.getOrgId()), "i");
         }*/
         
         return captureResDTO.getPicUrl();
    }
    
    @RequestMapping(value="/controlling", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="云台控制", notes = "云台控制")
    public void controlling(ControllerReqDTO controllerReqDTO) {
         hkService.controlling(controllerReqDTO);
    }
    
    
    /**
   	 * 国家局数据
   	 */
       public void gjjjk(Integer id, Integer orgId,String czbz) {
         
    	  String tableName = "ODS_UP_CNSPTXXXJK";
   		/**
            * restTemplate调用
            */
           //String url = "http://localhost:9022/recPublish/sendMessage";//
           //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
   		
        MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
   		sendMap.add("tableName", tableName);
   		sendMap.add("czbz", czbz);
   		sendMap.add("ywId", id);
   		sendMap.add("orgId", orgId);

        restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
           
    	
       }
       
       
     /**
      * 获取TaskId
      * @param cameraIndexCode
      * @return
      */
       @RequestMapping(value="/getTaskId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
       @ApiOperation(value="根据cameraIndexCode获取 taskId", notes = "根据cameraIndexCode获取 taskId")
       public String getTaskId(String cameraIndexCode) {
       	
           return cameraRecordService.getTaskId(cameraIndexCode);
       }
    
       /**
        * 批量获取监控点的预置点信息
        * @param PresetsReqDTO
        * @return
        */
       @RequestMapping(value="/getPresets", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
       @ApiOperation(value="批量获取监控点的预置点信息", notes = "批量获取监控点的预置点信息")
       public PresetsResDTO getPresets(@RequestBody PresetsReqDTO presetsReqDTO) {
           return hkService.getPresets(presetsReqDTO);
       }
}
