package com.chinaitop.depot.monitor.controller;

import com.chinaitop.depot.monitor.model.*;
import com.chinaitop.depot.monitor.service.QualityDlagService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/20 0020
 * 质量诊断计划和结果类
 */
@RestController
@RequestMapping(value = "/quality")
@Api(description = "质量诊断计划和结果类")
public class QualityDlagController {

    @Resource
    private QualityDlagService qualityDlagService;

    @RequestMapping(value = "/getPlanList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "计划列表",notes = "获取计划列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<DiagPlan> getPlanList(Integer pageNum, Integer pageSize,Integer orgId){
        DiagPlanExample example = new DiagPlanExample();
        DiagPlanExample.Criteria criteria = example.createCriteria();

        criteria.andOrgIdEqualTo(orgId);//增加组织id查询

        example.setOrderByClause("updatetime desc");

        PageHelper.startPage(pageNum, pageSize);
        List<DiagPlan> list = qualityDlagService.selectByExampleForPlan(example);
        PageInfo<DiagPlan> pageInfo = new PageInfo<DiagPlan>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getPlanById", method = RequestMethod.GET)
    @ApiOperation(value = "获取计划信息",notes = "获取计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "计划id", paramType = "query")
    })
    public DiagPlan getPlanById(Integer planId){
        return qualityDlagService.selectPlanById(planId);
    }

    @RequestMapping(value = "/planSave", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存计划",notes = "保存计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planJson", value = "保存的计划信息", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "form"),
            @ApiImplicitParam(name = "userId", value = "用户id", paramType = "form")
    })
    public Map<String,String> planSave(String planJson,Integer orgId,Integer userId) {
        Map<String,String> map = new HashMap<String, String>();
        qualityDlagService.savePlan(planJson,orgId,userId);
        map.put("status","success");
        return map;
    }

    @RequestMapping(value = "/removePlanById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "删除计划",notes = "根据id删除计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "计划id", paramType = "form")
    })
    public Map<String,String> removePlanById(Integer planId){
        Map<String,String> map = new HashMap<String, String>();
        qualityDlagService.removePlanById(planId);
        map.put("status","success");
        return map;
    }

    @RequestMapping(value = "/getResultNewList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "最新结果列表",notes = "获取最新结果列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "cameraName", value = "摄像头名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getResultNewList(Integer pageNum, Integer pageSize,String cameraName,Integer orgId){
        Map<String,Object> map = new HashMap<>();

        if(ParameterUtil.isnotnull(cameraName)){
            map.put("cameraName"," c.alias like '%"+cameraName+"%'");
        }

        if(ParameterUtil.isnotnull(orgId)){
            map.put("orgId",orgId);
        }

        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = qualityDlagService.selectNewTimeList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        //处理驼峰命名大写问题
        List<Map<String, Object>> page_list = ParameterUtil.slashCapitals(pageInfo.getList());
        pageInfo.setList(page_list);
        return pageInfo;
    }

    @RequestMapping(value = "/getResultList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "结果列表",notes = "获取结果列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "cameraId", value = "摄像头ID", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getResultList(Integer pageNum, Integer pageSize,String cameraId,Integer orgId){
        Map<String,Object> map = new HashMap<>();

        if(ParameterUtil.isnotnull(cameraId)){
            map.put("cameraid"," mc.id ='"+cameraId+"'");
        }
        if(ParameterUtil.isnotnull(orgId)){
            map.put("orgid",orgId);
        }

        PageHelper.startPage(pageNum, pageSize);
        List<Map<String,Object>> list = qualityDlagService.selectByExampleForResult(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        //处理驼峰命名大写问题
        List<Map<String, Object>> page_list = ParameterUtil.slashCapitals(pageInfo.getList());
        pageInfo.setList(page_list);
        return pageInfo;
    }

    @RequestMapping(value = "/getCameraErrCount", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "异常摄像头总数",notes = "获取异常摄像头总数")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public Map<String,Object> getCountForZdResult(Integer orgId){
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId);
        Integer count = qualityDlagService.getCountForZdResult(map);
        map.put("count",count);
        return map;
    }

    @RequestMapping(value = "/getResultEdit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "结果详情",notes = "获取结果详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getResultEdit(Integer id){
        DiagResultExample example = new DiagResultExample();
        DiagResultExample.Criteria criteria = example.createCriteria();
        criteria.andIdEqualTo(id);

        Map<String,Object> map = new HashMap<>();
        if(ParameterUtil.isnotnull(id)){
            map.put("id",id);
        }

        PageHelper.startPage(1, 10);
        List<Map<String,Object>> list = qualityDlagService.selectByExampleForResult(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        //处理驼峰命名大写问题
        List<Map<String, Object>> page_list = ParameterUtil.slashCapitals(pageInfo.getList());
        pageInfo.setList(page_list);
        return pageInfo;
    }

    @RequestMapping(value = "/getKindList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "阈值管理",notes = "获取阈值管理")
    public List<DiagKind> getKindList(){

        DiagKindExample example = new DiagKindExample();
        DiagKindExample.Criteria criteria = example.createCriteria();

        List<DiagKind> list = qualityDlagService.selectByExampleForKind(example);

        return list;
    }

    @RequestMapping(value = "/updateKindList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "修改阈值",notes = "修改阈值")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键id", paramType = "form"),
            @ApiImplicitParam(name = "ThresholdValue", value = "新分值", paramType = "form")
    })
    public Map<String, Object> updateKindList(Integer id, Integer ThresholdValue){
        Map<String, Object> kindMap = new HashMap<>();
        try {
            DiagKind kind = new DiagKind();
            kind.setId(id);
            kind.setNewScore(ThresholdValue);
            qualityDlagService.updateByPrimaryKeySelective(kind);
            kindMap.put("status", "success");
        } catch (Exception e) {
            kindMap.put("status", "error");
            e.printStackTrace();
        }
        return kindMap;
    }

    @RequestMapping(value = "/allSave", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "一键修改阈值",notes = "一键修改阈值")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "val", value = "修改的值", paramType = "form"),
            @ApiImplicitParam(name = "index", value = "修改的字段id", paramType = "form")
    })
    public Map<String, Object> allSave(String val,String index){
        Map<String, Object> kindMap = new HashMap<>();
        try {
            qualityDlagService.allSave(val,index);
            kindMap.put("status", "success");
        } catch (Exception e) {
            kindMap.put("status", "error");
            e.printStackTrace();
        }
        return kindMap;
    }

}
