package com.chinaitop.depot.monitor.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import com.chinaitop.depot.monitor.mapper.DiagPlanMapper;
import org.quartz.CronScheduleBuilder;
import org.quartz.CronTrigger;
import org.quartz.Scheduler;
import org.quartz.TriggerBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.chinaitop.depot.monitor.mapper.DiagKindMapper;
import com.chinaitop.depot.monitor.mapper.DiagResultMapper;
import com.chinaitop.depot.monitor.mapper.GroupMapper;
import com.chinaitop.depot.monitor.model.DiagKind;
import com.chinaitop.depot.monitor.model.DiagKindExample;
import com.chinaitop.depot.monitor.model.DiagPlan;
import com.chinaitop.depot.monitor.model.DiagPlanExample;
import com.chinaitop.depot.monitor.model.Group;
import com.chinaitop.depot.monitor.model.GroupExample;
import com.chinaitop.depot.monitor.model.MonitorJobEnty;
import com.chinaitop.depot.monitor.service.QualityDlagService;
import com.chinaitop.depot.monitor.service.quartzJob.Constant.MonitorStatus;
import com.chinaitop.depot.monitor.service.quartzJob.MonitorUtils;
import com.chinaitop.depot.monitor.service.quartzJob.QuartyThread;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;

/**
 * @auther mafy
 * @createtime 2017/10/20 0020
 * 质量诊断service实现类
 */
@Service
public class QualityDlagServiceImpl implements QualityDlagService {

    @Resource
    private DiagPlanMapper diagPlanMapper;//计划表对应的mapper

    @Resource
    private DiagResultMapper diagResultMapper;//结果表对应的mapper
    @Resource
    private DiagKindMapper diagKindMapper;//阈值管理对应的mapper

    @Resource
    private GroupMapper groupMapper;//分组接口
    
    @Autowired
    private Scheduler scheduler;

    //@Resource
    //private DepotScheduler myScheduler;//定时器

    //定时组名,出发器组，任务组为同一个名字，触发器名和任务名一样，每一个定时任务都不一样
    private static final String quartzGroup = "qualityGroup";
    //定时器 实现类
    private static final String quartzClass = "com.chinaitop.depot.monitor.service.quartzJob.QualityJob";

    public static String getQuartzGroup() {
        return quartzGroup;
    }

    public static String getQuartzClass() {
        return quartzClass;
    }

    /**
	 * 项目启动时，初始化定时器
	 */
//	@PostConstruct
//	public void init() {
//		DiagPlanExample example = new DiagPlanExample();
//		List<DiagPlan> diagPlanList = diagPlanMapper.selectByExample(example);
//		for(DiagPlan list:diagPlanList) {
//			CronTrigger cronTrigger = MonitorUtils.getCronTrigger(scheduler, list.getQuartzid());
//			if(!ObjectUtils.toString(list.getQuartztime(),"").isEmpty()) {
//				//设置定时任务的时间触发规则
//				CronScheduleBuilder scheduleBuilder = CronScheduleBuilder.cronSchedule(list.getQuartztime());
//				CronTrigger cronTriggers = TriggerBuilder.newTrigger().withIdentity(list.getQuartzid(),quartzGroup) .withSchedule(scheduleBuilder).build();
//				MonitorJobEnty monitorJob = new MonitorJobEnty();
//				monitorJob.setId(list.getQuartzid());
//				monitorJob.setParams(list.getQuartzid());
//				monitorJob.setCronExpression(cronTriggers.getCronExpression());
//				monitorJob.setBeanName("MonitorJob");
//				monitorJob.setMethodName("run");
//				monitorJob.setCreateTime(new Date());
//				monitorJob.setStatus((byte)MonitorStatus.NORMAL.getValue());
//				monitorJob.setOrgId(list.getOrgId());
//				//如果不存在，则创建
//				if(cronTrigger == null) {
//					MonitorUtils.createMonitorJob(scheduler, monitorJob);
//				}else {
//					MonitorUtils.updateMonitorJob(scheduler, monitorJob);
//				}
//			}
//		}
//	}

    /**
     * 诊断计划列表
     * @param example
     * @return
     */
    @Override
    public List<DiagPlan> selectByExampleForPlan(DiagPlanExample example) {

        List<DiagPlan> diagPlanList = diagPlanMapper.selectByExample(example);

        //获取到分组list，然后从里面获取对应的分组名称
        GroupExample groupExample = new GroupExample();
        List<Group> groupList = groupMapper.selectByExample(groupExample);

        Map<String,String> groupNameMap = new HashMap<String, String>();
        for (int i = 0; i < groupList.size(); i++) {//将group存入map里，当做字典使用
            String key = (groupList.get(i).getId()).toString();
            String val = groupList.get(i).getGroupname();
            groupNameMap.put(key,val);
        }
        // group存入map -结束
        for (int i = 0; i < diagPlanList.size(); i++) {
            List<String> stringsList = new ArrayList<String>();//放到 groupIds里
            String groupNames = "·";
            String[] groupid = (diagPlanList.get(i).getGroupId()).split(",");
            if(groupid.length>0){
                for (int j = 0; j < groupid.length; j++) {//从计划表查询的数据
                    groupNames+= groupNameMap.get(groupid[j])+"·";
                }
                diagPlanList.get(i).setGroupId(groupNames);
            }
            diagPlanList.get(i).setGroupIds(stringsList);
        }

        return diagPlanList;
    }

    /**
     * 获取可重复执行的计划
     * @return
     */
    public List<DiagPlan> selectRepeatPlan(){
        DiagPlanExample example = new DiagPlanExample();
        DiagPlanExample.Criteria criteria = example.createCriteria();
        criteria.andTypeEqualTo("0");//判断是自动执行
        return diagPlanMapper.selectByExample(example);
    }

    /**
     * 根据id获取计划
     * @param planId
     * @return
     */
    @Override
    public DiagPlan selectPlanById(Integer planId) {
        //获取到分组list，然后从里面获取对应的分组名称
        GroupExample groupExample = new GroupExample();
        List<Group> groupList = groupMapper.selectByExample(groupExample);
        Map<String,String> groupNameMap = new HashMap<String, String>();
        for (int i = 0; i < groupList.size(); i++) {//将group存入map里，当做字典使用
            String key = (groupList.get(i).getId()).toString();
            String val = groupList.get(i).getGroupname();
            groupNameMap.put(key,val);
        }

        DiagPlan diagPlan = diagPlanMapper.selectByPrimaryKey(planId);
        String[] groupStr = diagPlan.getGroupId().split(",");

        List<String> list = new ArrayList<String>();
            for (String str:groupStr) {
            list.add(str);
        }
        diagPlan.setGroupIds(list);
        return diagPlan;
    }
    
    /**
     * 根据定时id获取计划
     * @param quartzid
     * @return
     */
    @Override
    public DiagPlan selectPlanByQuartzid(String quartzid) {
    	DiagPlan diagPlan = diagPlanMapper.selectPlanByQuartzid(quartzid);
    	return diagPlan;
    }

    /**
     * 计划保存,包括即时诊断和定时诊断
     * @param planJson
     */
    @Override
    public Map<String,String> savePlan(String planJson,Integer orgId,Integer userId) {
        Map<String,String> retmap = new HashMap<String, String>();
        retmap.put("status","success");
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
            DiagPlan diagPlan;
            try {
                String newPlanJson = planJson.replaceAll("null","0").replaceAll("false","0").replaceAll("true","1");

                diagPlan =  (DiagPlan) mapper.readValue(newPlanJson, DiagPlan.class);//仅作为判断用
                //判断是否是即时诊断，获取对应的数据
                diagPlan = ParameterUtil.isequal("0",diagPlan.getType())?savePlanForDs(diagPlan,mapper,planJson):savePlanForJs(diagPlan);
                diagPlan.setOrgId(orgId);//设置机构id
                if(ParameterUtil.isnotnull(diagPlan.getId())){//修改
                    diagPlanMapper.updateByPrimaryKeySelective(diagPlan);
                    // 修改定时器-暂注释掉
                    //myScheduler.modifyJobTime(diagPlan.getQuartzid(),quartzGroup,diagPlan.getQuartztime()); //修改定时器
                    //设置定时任务的时间触发规则
                    if(ParameterUtil.isequal("1",diagPlan.getType())){//1位立即执行
                        // 立即制定定时任务-暂注释掉
                        new Thread(new QuartyThread(diagPlan)).start();
                    }else {
                    	CronScheduleBuilder scheduleBuilder = CronScheduleBuilder.cronSchedule(diagPlan.getQuartztime());
                    	CronTrigger cronTrigger = TriggerBuilder.newTrigger().withIdentity(diagPlan.getQuartzid(),quartzGroup) .withSchedule(scheduleBuilder).build();
                    	MonitorJobEnty monitorJob = new MonitorJobEnty();
                    	monitorJob.setId(diagPlan.getQuartzid());
                    	monitorJob.setParams(diagPlan.getQuartzid());
                    	monitorJob.setCronExpression(cronTrigger.getCronExpression());
                    	monitorJob.setBeanName("MonitorJob");
                    	monitorJob.setMethodName("run");
                    	monitorJob.setCreateTime(new Date());
                    	monitorJob.setStatus((byte)MonitorStatus.NORMAL.getValue());
                    	monitorJob.setOrgId(orgId);
                    	monitorJob.setCreaterId(userId);
                    	// 更新定时任务
                    	MonitorUtils.updateMonitorJob(scheduler, monitorJob);
                    }	
                }else{//新增
                    diagPlan.setQuartzid(UUID.randomUUID().toString());//设置触发器id,修改和删除都需要这个
                    diagPlanMapper.insertSelective(diagPlan);

                    if(ParameterUtil.isequal("1",diagPlan.getType())){//1位立即执行
                        // 立即制定定时任务-暂注释掉
                        new Thread(new QuartyThread(diagPlan)).start();
                    }else{
                        Map<String,Object> map = new HashMap<String,Object>();//定时器传参数用
                        //map.put(DepotScheduler.QUARTZID, NeedQuartz.QUALITY);
                        map.put("groupids", diagPlan.getGroupId());
                        
                        // 新增定时器-暂注释掉
                        //myScheduler.addJob(diagPlan.getQuartztime(),quartzGroup,diagPlan.getQuartzid(),Class.forName(quartzClass),map);
                        //设置定时任务的时间触发规则
                        CronScheduleBuilder scheduleBuilder = CronScheduleBuilder.cronSchedule(diagPlan.getQuartztime());
                        CronTrigger cronTrigger = TriggerBuilder.newTrigger().withIdentity(diagPlan.getQuartzid(),quartzGroup) .withSchedule(scheduleBuilder).build();
                        MonitorJobEnty monitorJob = new MonitorJobEnty();
                        monitorJob.setId(diagPlan.getQuartzid());
                        monitorJob.setParams(diagPlan.getQuartzid());
                        monitorJob.setCronExpression(cronTrigger.getCronExpression());
                        monitorJob.setBeanName("MonitorJob");
                        monitorJob.setMethodName("run");
                        monitorJob.setCreateTime(new Date());
                        monitorJob.setStatus((byte)MonitorStatus.NORMAL.getValue());
                        monitorJob.setOrgId(orgId);
                        monitorJob.setCreaterId(userId);
                        // 创建定时任务
                        MonitorUtils.createMonitorJob(scheduler, monitorJob);
                    }
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            return retmap;
    }


    /**
     * 及时检测的方法
     * @param diagPlan
     */
    private DiagPlan savePlanForJs(DiagPlan diagPlan){
        diagPlan.setGroupId(diagPlan.getGroupIds().toString().replaceAll("\\[","").replaceAll("\\]","").replaceAll(" ",""));
        /*diagPlan.setIsrepeat("0");//设置为不重复
        diagPlan.setPlandate("");//定时时间置空
        diagPlan.setPlantime(ParameterUtil.getSysDateTime());
        diagPlan.setDetailtime("具体时间点"+ParameterUtil.getSysDateTime());*/
        diagPlan.setQuartztime("");//定时器时间
        diagPlan.setDetailtime("立即执行"+"-"+diagPlan.getPlantime());
        diagPlan.setDetailtext(getDiagNeed(diagPlan));//需要的诊断项，显示用
        diagPlan.setCreateTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改、新增时间
        return diagPlan;
    }

    //设置定时数据
    private DiagPlan savePlanForDs(DiagPlan diagPlan,ObjectMapper mapper,String planJson) throws Exception{
        if(ParameterUtil.isnotnull(diagPlan.getId())){//修改
            diagPlan =  (DiagPlan) mapper.readValue(planJson.replaceAll("false","0").replaceAll("true","1"), DiagPlan.class);
        }else{//新增
            diagPlan =  (DiagPlan) mapper.readValue(planJson.replaceAll("null","0").replaceAll("false","0").replaceAll("true","1"), DiagPlan.class);
        }
        diagPlan.setDetailtime("每"+ WeekBean.getWeakName(diagPlan.getPlandate())+"-"+diagPlan.getPlantime());//新增页面展现用的具体时间：每天的12:00:00进行操作
        diagPlan.setQuartztime(getQuartzTime(diagPlan));//定时器时间
//        diagPlan.setDetailtext(getDiagNeed(diagPlan));//需要的诊断项，显示用
        diagPlan.setDetailtext("断网诊断");//需要的诊断项，显示用
        diagPlan.setGroupId(diagPlan.getGroupIds().toString().replaceAll("\\[","").replaceAll("\\]","").replaceAll(" ",""));
        diagPlan.setCreateTime(ParameterUtil.string2date(ParameterUtil.getSysDateTime()));//修改、新增时间
        return diagPlan;
    }



    //判断15项诊断中需要诊断的项
    private String getDiagNeed(DiagPlan diagPlan){
        StringBuilder needDiag = new StringBuilder();
        if(ParameterUtil.isnotnull(diagPlan.getBlur()) && ParameterUtil.isequal("1",diagPlan.getBlur().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.BLUR)) ;
        if(ParameterUtil.isnotnull(diagPlan.getChroma()) && ParameterUtil.isequal("1",diagPlan.getChroma().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.CHROMA)) ;
        if(ParameterUtil.isnotnull(diagPlan.getFreeze()) && ParameterUtil.isequal("1",diagPlan.getFreeze().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.FREEZE)) ;
        if(ParameterUtil.isnotnull(diagPlan.getScene()) && ParameterUtil.isequal("1",diagPlan.getScene().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.SCENE)) ;
        if(ParameterUtil.isnotnull(diagPlan.getPtz()) && ParameterUtil.isequal("1",diagPlan.getPtz().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.PTZ)) ;
        if(ParameterUtil.isnotnull(diagPlan.getContrast()) && ParameterUtil.isequal("1",diagPlan.getContrast().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.CONTRAST)) ;
        if(ParameterUtil.isnotnull(diagPlan.getBright()) && ParameterUtil.isequal("1",diagPlan.getBright().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.BRIGHT)) ;
        if(ParameterUtil.isnotnull(diagPlan.getDark()) && ParameterUtil.isequal("1",diagPlan.getDark().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.DARK)) ;
        if(ParameterUtil.isnotnull(diagPlan.getMono()) && ParameterUtil.isequal("1",diagPlan.getMono().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.MONO)) ;
        if(ParameterUtil.isnotnull(diagPlan.getNoise()) && ParameterUtil.isequal("1",diagPlan.getNoise().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.NOISE)) ;
        if(ParameterUtil.isnotnull(diagPlan.getStripe()) && ParameterUtil.isequal("1",diagPlan.getStripe().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.STRIPE)) ;
        if(ParameterUtil.isnotnull(diagPlan.getHake()) && ParameterUtil.isequal("1",diagPlan.getHake().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.HAKE)) ;
        if(ParameterUtil.isnotnull(diagPlan.getFlash()) && ParameterUtil.isequal("1",diagPlan.getFlash().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.FLASH)) ;
        if(ParameterUtil.isnotnull(diagPlan.getCover()) && ParameterUtil.isequal("1",diagPlan.getCover().toString())) needDiag.append(DiagPrigram.getCnName(DiagPrigram.COVER)) ;
        return needDiag.toString();
    }

    /**
     * 将正常时间改成定时时间，并且保存到数据库里
     * @param diagPlan
     */
    private String getQuartzTime(DiagPlan diagPlan){
        String quartzTime = "" ;
        String[] planTime = diagPlan.getPlantime().split(":");//:替代空格 09:10:00

        String weakName = diagPlan.getPlandate();//1-7,0是每天
        if(planTime.length>2){//表示定时时间有值
            if(ParameterUtil.isequal("EVE",WeekBean.getEnWeakName(weakName))){//判断是不是每天进行计划
                quartzTime = planTime[2]+" "+planTime[1]+" "+planTime[0]+" * * ?";
            }else{
                quartzTime = planTime[2]+" "+planTime[1]+" "+planTime[0]+" * ? "+WeekBean.getEnWeakName(weakName);
            }
            return quartzTime;
        }
        return null;
    }

    //移除计划
    @Override
    public void removePlanById(Integer planId) {
        DiagPlan diagPlan = diagPlanMapper.selectByPrimaryKey(planId);
        // 移除定时器-暂注释掉
      //myScheduler.deleteJob("quartzJob",quartzGroup);
        MonitorUtils.deleteScheduleJob(scheduler, diagPlan.getQuartzid());
        diagPlanMapper.deleteByPrimaryKey(planId);
    }



    /**
     * 诊断结果列表
     * @param map
     * @return
     */
    @Override
    public List<Map<String,Object>> selectByExampleForResult(Map<String,Object> map) {
        return diagResultMapper.getQualityResult(map);
    }

    /**
     * 条件查询最新结果列表
     *
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> selectNewTimeList(Map<String, Object> map) {

        return diagResultMapper.selectNewTimeList(map);
    }

    /**
     * 获取异常摄像头总数
     *
     * @param map
     * @return
     */
    @Override
    public Integer getCountForZdResult(Map<String, Object> map) {

        return diagResultMapper.selectCount(map);
    }


    /**
     * 阈值管理页面
     * @param example
     * @return
     */
    @Override
    public List<DiagKind> selectByExampleForKind(DiagKindExample example) {
        return diagKindMapper.selectByExample(example);
    }

    /**
     * 修改阈值
     * @param kind
     * @return
     */
    @Override
    public void updateByPrimaryKeySelective(DiagKind kind) {
        diagKindMapper.updateByPrimaryKeySelective(kind);
    }

    /**
     * 一键修改阈值
     *
     * @param val
     * @param index
     * @return
     */
    @Override
    public void allSave(String val, String index) {
        Map<String,Object> map = new HashMap<>();
        map.put("id",index.substring(0,index.length()-1));
        String[] valArr = val.split(",");
        for (int i = 65; i < valArr.length+65; i++) {
            map.put(String.valueOf((char)i),Integer.parseInt(valArr[i-65]));
        }
        diagKindMapper.allSave(map);
    }


    //根据定时器id获取计划内容
    public DiagPlan getDlagPlanByQuartzId(String quartzId){

        DiagPlanExample diagPlanExample = new DiagPlanExample();
        DiagPlanExample.Criteria criteria = diagPlanExample.createCriteria();
        criteria.andQuartzidEqualTo(quartzId);

        List<DiagPlan> diagPlanList = diagPlanMapper.selectByExample(diagPlanExample);
        return diagPlanList.size()>0?diagPlanList.get(0):new DiagPlan();
    }
}
