package com.chinaitop.depot.supervise.controller;

import com.chinaitop.depot.supervise.mapper.model.DepotStyle;
import com.chinaitop.depot.supervise.mapper.model.DepotStyleExample;
import com.chinaitop.depot.supervise.service.depotStyleService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @auther mafy
 * @createtime 2017/10/28 0028
 */
@RestController
@RequestMapping(value = "/depotStyle")
@Api(description = "库区全景类")
public class depotStyleController {

    @Resource
    private depotStyleService Service;

    /**
     * 查找所有的点图信息
     * @return
     */
    @RequestMapping(value="/getAllPointChart", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="点图信息", notes = "查找所有的点图信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "查看的类型", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public List<Map<String,Object>> getAllPointChart(String type, String orgId) {
        Map<String,Object> map = new HashMap<>();

        Map<String,Object> newMap = new HashMap<>();
        map.put("type", type);
        map.put("orgId", orgId);
        List<Map<String,Object>> list = null;
        if(ParameterUtil.isequal(type,"1")){//监控
            list = Service.getCameraPoint(map);
        }else if(ParameterUtil.isequal(type,"2")){//粮情
            list = Service.getGrainsituation(map);
            //拼接点位图信息
            DepotStyleExample example = new DepotStyleExample();
            DepotStyleExample.Criteria criteria = example.createCriteria();
            criteria.andTypeEqualTo(type);
            criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
            List<DepotStyle> typeList = Service.selectPoint(example);
            for (int i = 0; i < list.size(); i++) {
                newMap = list.get(i);
                for (DepotStyle depotS:typeList) {
                    //如果仓房id相同则拼接信息
                    if(ParameterUtil.isequal(depotS.getIndexid(),newMap.get("houseid"))){
                        newMap.put("styles", depotS.getStyles());
                        newMap.put("imgdata",new String((byte[]) depotS.getImgdata()));
                        list.set(i,newMap);
                        break;
                    }
                }
            }
        }else if(ParameterUtil.isequal(type,"3.1")){//作业-里面的通风，这个没用了，现在通风就一个环节，不存在处于哪个状态的说法
//            list = Service.selectWorkingForHouse(map);
            //list = Service.selectCLTask(map);
        }else if(ParameterUtil.isequal(type,"3.2")){//作业-里面的熏蒸，这个也没用了，现在熏蒸没有状态了
            list = Service.selectCLXZ(map);
        }else if(ParameterUtil.isequal(type,"3.3")){//入库
            map.put("billType",1);
            list = Service.selectRK(map);
        }else if(ParameterUtil.isequal(type,"3.4")){//出库
            map.put("billType",3);
            list = Service.selectCK(map);
        }else if(ParameterUtil.isequal(type,"4")){//储粮
            list = Service.selectLQForHouse(map);
            //拼接点位图信息
            DepotStyleExample example = new DepotStyleExample();
            DepotStyleExample.Criteria criteria = example.createCriteria();
            criteria.andTypeEqualTo(type);
            criteria.andOrgIdEqualTo(Integer.parseInt(orgId));
            List<DepotStyle> typeList = Service.selectPoint(example);
            for (int i = 0; i < list.size(); i++) {
                newMap = list.get(i);
                for (DepotStyle depotS:typeList) {
                    //如果仓房id相同则拼接信息
                    if(ParameterUtil.isequal(depotS.getIndexid(),newMap.get("houseid"))){
                        newMap.put("styles", depotS.getStyles());
                        newMap.put("imgdata",new String((byte[]) depotS.getImgdata()));
                        list.set(i,newMap);
                        break;
                    }
                }
            }
        }
        return ParameterUtil.slashCapitals(list);
    }

    /**
     * 查找仓房状态
     * @return
     */
    @RequestMapping(value="/getHouseStatePointChart", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="仓房状态信息", notes = "查找仓房状态信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
    })
    public Map<String,Object> getHouseStatePointChart(Integer orgId) {
        Map<String,Object> map = new HashMap<>();
        map.put("orgId", orgId);
        Map<String,Object> newMap = new HashMap<>();
        List<Map<String,Object>> list = null;
        list = Service.getHouseStatePointChart(map);
        for (int i = 0; i < list.size(); i++) {
            newMap = list.get(i);
            if(newMap.get("imgdata")!=null){
                newMap.put("imgdata",new String((byte[]) newMap.get("imgdata")));
                list.set(i,newMap);
            }
        }
        if(list.size() > 0){
            map.put("houseData",ParameterUtil.slashCapitals(list));
        }else{
            map.put("houseData","null");
        }
        return map;
    }

    /**
     * 查找单个作业点位图信息
     * @return
     */
    @RequestMapping(value="/getSinglePointChart", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="单个作业点位图信息", notes = "查找单个作业点位图信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "indexid", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "查看的类型", paramType = "query")
    })
    public List<DepotStyle> getSinglePointChart(String indexid,String type) {
        DepotStyleExample example = new DepotStyleExample();
        DepotStyleExample.Criteria criteria = example.createCriteria();
        criteria.andIndexidEqualTo(Integer.valueOf(indexid));
        criteria.andTypeEqualTo(type);
        List<DepotStyle> list = Service.selectPoint(example);
        return list;
    }

    /**
     * 查找全部作业点位图信息
     * @return
     */
    @RequestMapping(value="/getAllSinglePointChart", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="全部作业点位图信息", notes = "查找全部作业点位图信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "indexid", value = "仓房ID", paramType = "query")
    })
    public List<DepotStyle> getAllSinglePointChart(String indexid) {
        DepotStyleExample example = new DepotStyleExample();
        DepotStyleExample.Criteria criteria = example.createCriteria();
        criteria.andIndexidEqualTo(Integer.valueOf(indexid));
        criteria.andTypeLike("3._");
        List<DepotStyle> list = Service.selectPoint(example);
        return list;
    }

    /**
     * 新增触发区域点图数据
     * @return
     */
    @RequestMapping(value="/addAreaPoint", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增触发区域点图数据", notes = "新增触发区域点图数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "indexid", value = "仓房ID", paramType = "form"),
            @ApiImplicitParam(name = "type", value = "查看的类型", paramType = "form"),
            @ApiImplicitParam(name = "styles", value = "点位信息", paramType = "form"),
            @ApiImplicitParam(name = "imgdata", value = "触发区域图片", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "form")
    })
    public Map<String, Object> addAreaPoint(String indexid,String type,String styles,String imgdata,Integer orgId){
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            DepotStyle depotStyle = new DepotStyle();
            depotStyle.setIndexid(Integer.valueOf(indexid));
            depotStyle.setOrgId(orgId);
            depotStyle.setType(type);
            depotStyle.setStyles(styles);
            depotStyle.setImgdata(imgdata.getBytes());
            Service.deletePoint(depotStyle);
            Service.addPoint(depotStyle);
            modelMap.put("status", "success");
        }catch (Exception e){
            e.printStackTrace();
            modelMap.put("status","error");
        }
        return modelMap;
    }

    /**
     * 新增点图数据
     * @return
     */
    @RequestMapping(value="/addPoint", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增点图数据", notes = "新增点图数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "indexid", value = "仓房ID", paramType = "form"),
            @ApiImplicitParam(name = "pointData", value = "点位信息", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "form")
    })
    public Map<String, Object> addPoint(String indexid,String pointData,Integer orgId){
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            DepotStyle depotStyle = new DepotStyle();
            depotStyle.setIndexid(Integer.valueOf(indexid));
            depotStyle.setOrgId(orgId);
            JsonParser parser = new JsonParser();
            JsonArray jsonArray = parser.parse(pointData).getAsJsonArray();
            for(int i = 0;i<jsonArray.size();i++){
                JsonObject jsonObject = new JsonParser().parse(jsonArray.get(i).toString()).getAsJsonObject();
                depotStyle.setType(jsonObject.get("type").toString());
                depotStyle.setStyles(jsonObject.get("styles").toString());
                Service.deletePoint(depotStyle);
                Service.addPoint(depotStyle);
            }
            modelMap.put("status", "success");
        }catch (Exception e){
            e.printStackTrace();
            modelMap.put("status","error");
        }
        return modelMap;
    }

    /**
     * 新增摄像头点位图
     * @return
     */
    @RequestMapping(value="/addSXTPoint", produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="新增摄像头点位图", notes = "新增摄像头点位图")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "indexid", value = "仓房ID", paramType = "form"),
            @ApiImplicitParam(name = "styles", value = "点位信息", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "form")
    })
    public Map<String, Object> addPoint(String indexid,String type,String styles,Integer orgId){
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try{
            DepotStyle depotStyle = new DepotStyle();
            depotStyle.setIndexid(Integer.valueOf(indexid));
            depotStyle.setOrgId(orgId);
            depotStyle.setType(type);
            depotStyle.setStyles(styles);
            Service.deleteSxtPoint(depotStyle);
            Service.addSxtPoint(depotStyle);
            modelMap.put("status", "success");
        }catch (Exception e){
            e.printStackTrace();
            modelMap.put("status","error");
        }
        return modelMap;
    }
}
