package com.chinaitop.depot.supervise.service.impl;


import com.chinaitop.depot.supervise.mapper.TestDatasMapper;
import com.chinaitop.depot.supervise.service.GrainConditionService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class GrainConditionServiceImpl implements GrainConditionService {

    @Resource
    private TestDatasMapper testDatasMapper;

    /**
     * 获取最新仓房温度列表
     *
     * @return
     */
    @Override
    public List<Map<String, Object>> getDataList(String houseNo, String orgId) {
        Map<String,String> map = new HashMap<String, String>();
        if(!StringUtils.isEmpty(houseNo)){
            map.put("houseNo",houseNo);
        }
        map.put("orgId",orgId);
        return testDatasMapper.getDataList(map);
    }

    /**
     * 根据仓房id查询对应仓房温度
     * @param houseId
     * @return
     */
    @Override
    public Map<String, Object> getTempByHouseNo(String houseId,String orgId) {
        Map<String,String> map = new HashMap<>();
        map.put("houseId",houseId);
        map.put("orgId",orgId);

        return testDatasMapper.getTempByHouseNo(map);
    }

    /**
     * 根据仓房BH获取三温曲线图
     * @param example
     * @return
     */
    @Override
    public List<Map<String,Object>> getThreeCondition(Map<String,Object> example) {
        return testDatasMapper.selectByDays(example);
    }

    /**
     * 根据仓房BH获取三温曲线图--首页用到
     * @param example
     * @return
     */
    @Override
    public List<Map<String,Object>> getThreeConditionHomePage(Map<String,Object> example) {
        return testDatasMapper.selectByHours(example);
    }

    /**
     * 给pad端提供的三温图的数据接口
     *
     * @param example
     * @return
     */
    @Override
    public List<Map<String, Object>> getThreeConditionForPad(Map<String, Object> example) {
        example.put("dayNum",Integer.parseInt(example.get("dayCount").toString())-1);
        String houseMaxTime = testDatasMapper.selectHouseMaxTime(example);
        int days = Integer.parseInt(example.get("dayCount").toString());
        example.put("houseMaxTime",houseMaxTime);
        List<Map<String,Object>> three = testDatasMapper.getThreeConditionForPad(example);
        List<Map<String,Object>> threeTemperature = new ArrayList<Map<String,Object>>();
        String times;//获取最新检测时间，如果没有数据则获取当天
        if(three.size() == 0){
            times = ParameterUtil.getSysDate();
        }else{
            times = ObjectUtils.toString(three.get(0).get("days")).substring(0,10);
        }
        for(int i = 0;i<days;i++){
            Map<String, Object> mapList = new HashMap<String, Object>();
            mapList.put("days",times);
            mapList.put("maxs",null);
            mapList.put("mins",null);
            mapList.put("lswd",null);
            mapList.put("zgwd",null);
            mapList.put("zdwd",null);
            mapList.put("cwwd",null);
            mapList.put("cnwd",null);
            threeTemperature.add(mapList);
            times = ParameterUtil.dellOneDay(times);//时间减一天存入
        }

        if(three.size() != 0){
            String maxTime = ObjectUtils.toString(three.get(0).get("days")).substring(0,10);
            int index = 0;
            for (Map<String,Object> maps:three){
                String dateList = ObjectUtils.toString(maps.get("days")).substring(0,10);
                for(int i = index;i<days;i++){
                    if (ParameterUtil.isequal(dateList,maxTime)){
                        maps.put("days",ObjectUtils.toString(maps.get("days")).substring(0,10));
                        threeTemperature.set(i,maps);
                        break;
                    }
                    index++;
                    maxTime = ParameterUtil.dellOneDay(maxTime);//时间减一天存入
                }
            }
        }

        return threeTemperature;
    }
}
