package com.chinaitop.depot.hk.service;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.DepotMonitorApplication;
import com.chinaitop.depot.hk.constant.HkProtocolEnum;
import com.chinaitop.depot.hk.dto.req.*;
import com.chinaitop.depot.hk.dto.res.*;
import lombok.extern.slf4j.Slf4j;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;

@RunWith(SpringRunner.class)
@SpringBootTest(classes = DepotMonitorApplication.class)
@Slf4j
public class HkServiceTest {

    @Resource
    private HkService hkService;

    @Test
    public void getRegions() {
        PageResDTO<RegionResDTO> pageResDTO = hkService.getRegions(new PageReqDTO(1, 30));
        log.info("pageResDTO:{}", JSON.toJSONString(pageResDTO));
    }

    @Test
    public void getCameras() {
        PageResDTO<CamerasResDTO> pageResDTO = hkService.getCameras(new PageReqDTO(1, 30));
        log.info("pageResDTO:{}", JSON.toJSONString(pageResDTO));
    }

    @Test
    public void getCamera() {
        CameraResDTO cameraResDTO = hkService.getCamera(new CameraReqDTO("92768838d53b42788431697b657a507e"));
        log.info("cameraResDTO:{}", JSON.toJSONString(cameraResDTO));
    }

    @Test
    public void previewURLs() {
        PreviewResDTO previewResDTO = hkService.previewURLs(new PreviewReqDTO("92768838d53b42788431697b657a507e", HkProtocolEnum.WS));
        log.info("previewResDTO:{}", JSON.toJSONString(previewResDTO));
    }

    @Test
    public void playbackURLs() {
        PlaybackReqDTO playbackReqDTO = new PlaybackReqDTO();
        playbackReqDTO.setCameraIndexCode("1234");
        playbackReqDTO.setBeginTime("2017-06-14T00:00:00.000+08:00");
        playbackReqDTO.setEndTime("2017-06-14T23:59:59.000+08:00");
        log.info("playbackURLs:{}", JSON.toJSONString(hkService.playbackURLs(playbackReqDTO)));
    }

    @Test
    public void recordStart() {
        //log.info("recordStart:{}", JSON.toJSONString(hkService.recordStart(new RecordStartReqDTO("1234", 6, 1))));
    }

    @Test
    public void recordStop() {
        hkService.recordStop(new RecordStopReqDTO("1234", "1", 1));
    }

    @Test
    public void manualCapture() {
        //log.info("manualCapture:{}", JSON.toJSONString(hkService.manualCapture(new CaptureReqDTO("1234"))));
    }

    @Test
    public void controlling() {
        hkService.controlling(new ControllerReqDTO("1234", 1, "UP", 1, 1));
    }
}